@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2013 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -15,8 +15,6 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #include "addarchivemaildialog.h"
-#include "widgets/formatcombobox.h"
-#include "widgets/unitcombobox.h"
 #include "mailcommon/folder/folderrequester.h"
 
 #include <Akonadi/Collection>
@@ -55,7 +53,6 @@ AddArchiveMailDialog::AddArchiveMailDialog(ArchiveMailInfo *info,QWidget *parent
     QLabel *folderLabel = new QLabel( i18n( "&Folder:" ), mainWidget );
     mainLayout->addWidget( folderLabel, row, 0 );
     mFolderRequester = new MailCommon::FolderRequester( mainWidget );
-    mFolderRequester->setObjectName(QLatin1String("folder_requester"));
     mFolderRequester->setMustBeReadWrite( false );
     mFolderRequester->setNotAllowToCreateNewFolder( true );
     connect( mFolderRequester, SIGNAL(folderChanged(Akonadi::Collection)), SLOT(slotFolderChanged(Akonadi::Collection)) );
@@ -66,25 +63,26 @@ AddArchiveMailDialog::AddArchiveMailDialog(ArchiveMailInfo *info,QWidget *parent
     ++row;
 
     QLabel *formatLabel = new QLabel( i18n( "F&ormat:" ), mainWidget );
-    formatLabel->setObjectName(QLatin1String("label_format"));
     mainLayout->addWidget( formatLabel, row, 0 );
-    mFormatComboBox = new FormatComboBox( mainWidget );
-    mFormatComboBox->setObjectName(QLatin1String("format_combobox"));
+    mFormatComboBox = new KComboBox( mainWidget );
     formatLabel->setBuddy( mFormatComboBox );
 
 
+    // These combobox values have to stay in sync with the ArchiveType enum from BackupJob!
+    mFormatComboBox->addItem( i18n( "Compressed Zip Archive (.zip)" ) );
+    mFormatComboBox->addItem( i18n( "Uncompressed Archive (.tar)" ) );
+    mFormatComboBox->addItem( i18n( "BZ2-Compressed Tar Archive (.tar.bz2)" ) );
+    mFormatComboBox->addItem( i18n( "GZ-Compressed Tar Archive (.tar.gz)" ) );
+    mFormatComboBox->setCurrentIndex( 2 );
     mainLayout->addWidget( mFormatComboBox, row, 1 );
     ++row;
 
-
     mRecursiveCheckBox = new QCheckBox( i18n( "Archive all subfolders" ), mainWidget );
-    mRecursiveCheckBox->setObjectName(QLatin1String("recursive_checkbox"));
     mainLayout->addWidget( mRecursiveCheckBox, row, 0, 1, 2, Qt::AlignLeft );
     mRecursiveCheckBox->setChecked( true );
     ++row;
 
     QLabel *pathLabel = new QLabel( i18n( "Path:" ), mainWidget );
-    pathLabel->setObjectName(QLatin1String("path_label"));
     mainLayout->addWidget( pathLabel, row, 0 );
     mPath = new KUrlRequester(mainWidget);
     connect(mPath, SIGNAL(textChanged(QString)), this, SLOT(slotUpdateOkButton()));
@@ -93,7 +91,6 @@ AddArchiveMailDialog::AddArchiveMailDialog(ArchiveMailInfo *info,QWidget *parent
     ++row;
 
     QLabel *dateLabel = new QLabel( i18n( "Backup each:" ), mainWidget );
-    dateLabel->setObjectName(QLatin1String("date_label"));
     mainLayout->addWidget( dateLabel, row, 0 );
 
     QHBoxLayout * hlayout = new QHBoxLayout;
@@ -102,7 +99,13 @@ AddArchiveMailDialog::AddArchiveMailDialog(ArchiveMailInfo *info,QWidget *parent
     mDays->setMaximum(3600);
     hlayout->addWidget(mDays);
 
-    mUnits = new UnitComboBox(mainWidget);
+    mUnits = new KComboBox(mainWidget);
+    QStringList unitsList;
+    unitsList<<i18n("Days");
+    unitsList<<i18n("Weeks");
+    unitsList<<i18n("Months");
+    unitsList<<i18n("Years");
+    mUnits->addItems(unitsList);
     hlayout->addWidget(mUnits);
 
     mainLayout->addLayout(hlayout, row, 1);
@@ -112,7 +115,7 @@ AddArchiveMailDialog::AddArchiveMailDialog(ArchiveMailInfo *info,QWidget *parent
     mainLayout->addWidget( maxCountlabel, row, 0 );
     mMaximumArchive = new KIntSpinBox( mainWidget );
     mMaximumArchive->setMinimum(0);
-    mMaximumArchive->setMaximum(9999);
+    mMaximumArchive->setMinimum(9999);
     mMaximumArchive->setSpecialValueText(i18n("unlimited"));
     maxCountlabel->setBuddy( mMaximumArchive );
     mainLayout->addWidget( mMaximumArchive, row, 1 );
@@ -141,9 +144,9 @@ void AddArchiveMailDialog::load(ArchiveMailInfo *info)
     mPath->setUrl(info->url());
     mRecursiveCheckBox->setChecked(info->saveSubCollection());
     mFolderRequester->setCollection(Akonadi::Collection(info->saveCollectionId()));
-    mFormatComboBox->setFormat(info->archiveType());
+    mFormatComboBox->setCurrentIndex(static_cast<int>(info->archiveType()));
     mDays->setValue(info->archiveAge());
-    mUnits->setUnit(info->archiveUnit());
+    mUnits->setCurrentIndex(static_cast<int>(info->archiveUnit()));
     mMaximumArchive->setValue(info->maximumArchiveCount());
     slotUpdateOkButton();
 }
@@ -154,18 +157,18 @@ ArchiveMailInfo* AddArchiveMailDialog::info()
         mInfo = new ArchiveMailInfo();
     }
     mInfo->setSaveSubCollection(mRecursiveCheckBox->isChecked());
-    mInfo->setArchiveType(mFormatComboBox->format());
+    mInfo->setArchiveType(static_cast<MailCommon::BackupJob::ArchiveType>(mFormatComboBox->currentIndex()));
     mInfo->setSaveCollectionId(mFolderRequester->collection().id());
     mInfo->setUrl(mPath->url());
     mInfo->setArchiveAge(mDays->value());
-    mInfo->setArchiveUnit(mUnits->unit());
+    mInfo->setArchiveUnit(static_cast<ArchiveMailInfo::ArchiveUnit>(mUnits->currentIndex()));
     mInfo->setMaximumArchiveCount(mMaximumArchive->value());
     return mInfo;
 }
 
 void AddArchiveMailDialog::slotUpdateOkButton()
 {
-    const bool valid = (!mPath->lineEdit()->text().trimmed().isEmpty() && !mPath->url().isEmpty() && mFolderRequester->collection().isValid());
+    const bool valid = (!mPath->url().isEmpty() && mFolderRequester->collection().isValid());
     enableButtonOk(valid);
 }
 
@@ -177,12 +180,12 @@ void AddArchiveMailDialog::slotFolderChanged(const Akonadi::Collection& collecti
 
 void AddArchiveMailDialog::setArchiveType(MailCommon::BackupJob::ArchiveType type)
 {
-    mFormatComboBox->setFormat(type);
+    mFormatComboBox->setCurrentIndex((int)type);
 }
 
 MailCommon::BackupJob::ArchiveType AddArchiveMailDialog::archiveType() const
 {
-    return mFormatComboBox->format();
+    return static_cast<MailCommon::BackupJob::ArchiveType>(mFormatComboBox->currentIndex());
 }
 
 void AddArchiveMailDialog::setRecursive( bool b )
@@ -226,3 +229,4 @@ int AddArchiveMailDialog::maximumArchiveCount() const
 }
 
 
+#include "addarchivemaildialog.moc"
