@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2013 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -28,7 +28,7 @@
 #include <Akonadi/CollectionFetchScope>
 #include <KMime/Message>
 #include <KWindowSystem>
-#include <KLocale>
+
 #include <QTimer>
 #include <QPointer>
 
@@ -74,15 +74,10 @@ ArchiveMailAgent::~ArchiveMailAgent()
 
 void ArchiveMailAgent::setEnableAgent(bool enabled)
 {
-    if (enabled != ArchiveMailAgentSettings::enabled()) {
-        ArchiveMailAgentSettings::setEnabled(enabled);
-        ArchiveMailAgentSettings::self()->writeConfig();
-        if (!enabled) {
-            mTimer->stop();
-            pause();
-        } else {
-            mTimer->start();
-        }
+    ArchiveMailAgentSettings::setEnabled(enabled);
+    ArchiveMailAgentSettings::self()->writeConfig();
+    if (!enabled) {
+        pause();
     }
 }
 
@@ -150,20 +145,11 @@ void ArchiveMailAgent::resume()
     }
 }
 
-QString ArchiveMailAgent::printArchiveListInfo()
+void ArchiveMailAgent::printArchiveListInfo()
 {
-    return mArchiveManager->printArchiveListInfo();
-}
-
-QString ArchiveMailAgent::printCurrentListInfo()
-{
-    return mArchiveManager->printCurrentListInfo();
-}
-
-void ArchiveMailAgent::archiveFolder(const QString &path, Akonadi::Collection::Id collectionId)
-{
-    mArchiveManager->archiveFolder(path, collectionId);
+    mArchiveManager->printArchiveListInfo();
 }
 
 AKONADI_AGENT_MAIN( ArchiveMailAgent )
 
+#include "archivemailagent.moc"
