@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,6 +19,7 @@
 #define SENDLATERAGENT_H
 
 #include <akonadi/agentbase.h>
+#include "sendlaterdialog.h"
 
 class SendLaterManager;
 
@@ -31,7 +32,7 @@ public:
 
     void showConfigureDialog(qlonglong windowId = 0);
 
-    QString printDebugInfo();
+    void printDebugInfo();
 
     void setEnableAgent(bool b);
     bool enabledAgent() const;
@@ -47,14 +48,12 @@ public Q_SLOTS:
 private Q_SLOTS:
     void slotSendNow(Akonadi::Item::Id id);
 
-    void slotStartAgent();
 protected:
     void itemsRemoved( const Akonadi::Item::List &item );
     void itemsMoved(const Akonadi::Item::List &items, const Akonadi::Collection &sourceCollection, const Akonadi::Collection &destinationCollection);
     void doSetOnline( bool online );
 
 private:
-    bool mAgentInitialized;
     SendLaterManager *mManager;
 };
 
