@@ -468,7 +468,7 @@ void AgendaView::Private::calendarIncidenceChanged( const KCalCore::Incidence::P
   }
 
   // No need to call setChanges(), that triggers a fillAgenda()
-  // setChanges( q->changes() | IncidencesEdited, CalendarSupport::incidence( incidence ) );
+  // setChanges( q->changes() | IncidencesEdited, incidence );
 }
 
 void AgendaView::Private::calendarIncidenceDeleted( const KCalCore::Incidence::Ptr &incidence )
@@ -1344,7 +1344,7 @@ void AgendaView::createTimeBarHeaders()
 
   foreach ( QScrollArea *area, d->mTimeLabelsZone->timeLabels() ) {
     TimeLabels *timeLabel = static_cast<TimeLabels*>( area->widget() );
-    QLabel *label = new QLabel( timeLabel->header().replace( '/', "/ " ),
+    QLabel *label = new QLabel( timeLabel->header().replace( QLatin1Char('/'), QLatin1String("/ ") ),
                                 d->mTimeBarHeaderFrame );
     label->setFont( labelFont );
     label->setAlignment( Qt::AlignBottom | Qt::AlignRight );
@@ -1371,7 +1371,7 @@ void AgendaView::updateTimeBarWidth()
 
   int width = d->mTimeLabelsZone->preferedTimeLabelsWidth();
   foreach ( QLabel *l, d->mTimeBarHeaders ) {
-    foreach ( const QString &word, l->text().split( ' ' ) ) {
+    foreach ( const QString &word, l->text().split( QLatin1Char(' ') ) ) {
       width = qMax( width, fm.width( word ) );
     }
   }
@@ -2198,7 +2198,7 @@ CalendarDecoration::Decoration *AgendaView::Private::loadCalendarDecoration( con
   QString constraint;
   if ( version >= 0 ) {
     constraint =
-      QString( "[X-KDE-PluginInterfaceVersion] == %1" ).arg( QString::number( version ) );
+      QString::fromLatin1( "[X-KDE-PluginInterfaceVersion] == %1" ).arg( QString::number( version ) );
   }
 
   KService::List list = KServiceTypeTrader::self()->query( type, constraint );
