@@ -60,7 +60,7 @@ using namespace KCalCore;
 using namespace EventViews;
 using namespace Akonadi;
 
-static const KCatalogLoader loaderCatalog( "libeventviews" );
+static const KCatalogLoader loaderCatalog( QLatin1String("libeventviews") );
 
 CalendarSupport::CollectionSelection *EventViewPrivate::sGlobalCollectionSelection = 0;
 
@@ -669,6 +669,7 @@ QString EventView::iconForItem( const Akonadi::Item &item )
 void EventView::onCollectionChanged(const Akonadi::Collection &collection,
                                     const QSet<QByteArray> &changedAttributes)
 {
+  Q_UNUSED(collection);
   if (changedAttributes.contains("AccessRights")) {
       setChanges(changes() | EventViews::EventView::ResourcesChanged);
       updateView();
