@@ -85,12 +85,14 @@ public:
         Print,
         PrintPreview,
         PasteWithoutFormatting,
+        InsertAnchor,
 
         //Keep at end
         LastType
     };
 
     virtual void addCreatedActionsToActionCollection(KActionCollection *actionCollection);
+    virtual void addExtraAction(QMenu *menu);
 
     void createActions(const QList<ComposerViewAction> &);
 
