@@ -21,6 +21,7 @@
 #include "composerview_p.h"
 #include "utils/composereditorutils_p.h"
 #include "link/composerlinkdialog.h"
+#include "link/composeranchordialog.h"
 #include "list/composerlistdialog.h"
 #include "image/composerimagedialog.h"
 #include "table/composertabledialog.h"
@@ -464,6 +465,15 @@ void ComposerViewPrivate::createAction(ComposerView::ComposerViewAction type)
         }
         break;
     }
+    case ComposerView::InsertAnchor:
+    {
+        if (!action_insert_anchor) {
+            action_insert_anchor = new KAction(i18n( "Insert Anchor..." ), q);
+            htmlEditorActionList.append(action_insert_anchor);
+            q->connect( action_insert_anchor, SIGNAL(triggered()), q, SLOT(_k_slotInsertAnchor()) );
+        }
+        break;
+    }
     case ComposerView::Separator:
         //nothing
         break;
@@ -777,9 +787,10 @@ void ComposerViewPrivate::_k_slotReplace()
 void ComposerViewPrivate::_k_slotSaveAs()
 {
     QString fn = KFileDialog::getSaveFileName(QString(), i18n("HTML-Files (*.htm *.html);;All Files (*)") , q, i18n("Save as..."));
-    //TODO add KMessageBox
-    if (fn.isEmpty())
+    if (fn.isEmpty()) {
+        KMessageBox::error(q, i18n("Not file selected."), i18n("Save as"));
         return;
+    }
     if (!(fn.endsWith(QLatin1String(".htm"), Qt::CaseInsensitive) ||
           fn.endsWith(QLatin1String(".html"), Qt::CaseInsensitive))) {
         fn += QLatin1String(".htm");
@@ -948,6 +959,15 @@ void ComposerViewPrivate::_k_slotInsertSpecialChar()
     }
 }
 
+void ComposerViewPrivate::_k_slotInsertAnchor()
+{
+    QPointer<ComposerAnchorDialog> dlg = new ComposerAnchorDialog( q );
+    if (dlg->exec() == KDialog::Accepted) {
+        execCommand(QLatin1String("insertHTML"), dlg->html());
+    }
+    delete dlg;
+}
+
 QMap<QString, QString> ComposerViewPrivate::localImages() const
 {
     QMap<QString, QString> lst;
