@@ -15,27 +15,23 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
+
 #include "editorpage.h"
 #include "editorwidget.h"
 #include "previewwidget.h"
+#include "themeeditorwidget.h"
 #include "themetemplatewidget.h"
+#include "pimcommon/texteditor/plaintexteditor/plaintexteditor.h"
 
-#include <KTextEdit>
-#include <KTemporaryFile>
 #include <KLocale>
-#include <KZip>
+#include <KGlobal>
 #include <KConfigGroup>
-#include <KMessageBox>
 
 #include <QSplitter>
 #include <QVBoxLayout>
-#include <QTextStream>
-#include <QDir>
 
-EditorPage::EditorPage(PageType type, const QString &projectDirectory, QWidget *parent)
-    : QWidget(parent),
-      mType(type),
-      mPreview(0),
+EditorPage::EditorPage(GrantleeThemeEditor::EditorPage::PageType type, const QString &projectDirectory, QWidget *parent)
+    : GrantleeThemeEditor::EditorPage(type, parent),
       mWidgetSplitter(0)
 {
     QVBoxLayout *lay = new QVBoxLayout;
@@ -56,15 +52,19 @@ EditorPage::EditorPage(PageType type, const QString &projectDirectory, QWidget *
         lay->addWidget(mMainSplitter);
     }
 
-    mEditor = new EditorWidget;
+    mEditor = new ThemeEditorWidget;
 
+    if (mType == MainPage) {
+        KConfigGroup group( KGlobal::config(), QLatin1String("Global"));
+        mEditor->setPlainText(group.readEntry("defaultTemplate",QString()));
+    }
     mMainSplitter->addWidget(mEditor);
     mMainSplitter->setChildrenCollapsible(false);
     mThemeTemplate = new ThemeTemplateWidget(i18n("Theme Templates:"));
-    connect(mThemeTemplate, SIGNAL(insertTemplate(QString)), mEditor, SLOT(insertPlainText(QString)));
+    connect(mThemeTemplate, SIGNAL(insertTemplate(QString)), mEditor->editor(), SLOT(insertPlainText(QString)));
     mMainSplitter->addWidget(mThemeTemplate);
 
-    connect(mEditor, SIGNAL(textChanged()), this, SIGNAL(changed()));
+    connect(mEditor->editor(), SIGNAL(textChanged()), this, SIGNAL(changed()));
 
 
     if (mType == MainPage) {
@@ -86,79 +86,9 @@ EditorPage::~EditorPage()
     }
 }
 
-void EditorPage::insertFile(const QString &filename)
-{
-    mEditor->insertFile(filename);
-}
-
-void EditorPage::createZip(const QString &themeName, KZip *zip)
-{
-    KTemporaryFile tmp;
-    tmp.open();
-    saveAsFilename(tmp.fileName());
-    const bool fileAdded  = zip->addLocalFile(tmp.fileName(), themeName + QLatin1Char('/') + mPageFileName);
-    if (!fileAdded) {
-        KMessageBox::error(this, i18n("We can not add file in zip file"), i18n("Failed to add file."));
-    }
-}
-
-void EditorPage::loadTheme(const QString &path)
-{
-    QFile file(path);
-    if (file.open(QIODevice::Text|QIODevice::ReadOnly)) {
-        const QByteArray data = file.readAll();
-        const QString str = QString::fromUtf8(data);
-        file.close();
-        mEditor->setPlainText(str);
-    }
-}
-
-void EditorPage::saveTheme(const QString &path)
-{
-    const QString filename = path + QDir::separator() + mPageFileName;
-    saveAsFilename(filename);
-}
-
-void EditorPage::saveAsFilename(const QString &filename)
-{
-    QFile file(filename);
-    if (file.open(QIODevice::WriteOnly|QIODevice::Text)) {
-        QTextStream out(&file);
-        out.setCodec("UTF-8");
-        out << mEditor->toPlainText();
-        file.close();
-    }
-}
-
-void EditorPage::setPageFileName(const QString &filename)
-{
-    mPageFileName = filename;
-}
-
-QString EditorPage::pageFileName() const
-{
-    return mPageFileName;
-}
-
-void EditorPage::installTheme(const QString &themePath)
-{
-    const QString filename = themePath + QDir::separator() + mPageFileName;
-    saveAsFilename(filename);
-}
-
-PreviewWidget *EditorPage::preview() const
+GrantleeThemeEditor::PreviewWidget *EditorPage::preview() const
 {
     return mPreview;
 }
 
-EditorPage::PageType EditorPage::pageType() const
-{
-    return mType;
-}
-
-EditorWidget *EditorPage::editor() const
-{
-    return mEditor;
-}
-
 #include "editorpage.moc"
