@@ -25,6 +25,10 @@
 
 #include <QWidget>
 
+namespace GrantleeTheme {
+class GrantleeThemeManager;
+}
+
 namespace Akonadi {
   class Collection;
   class ContactGroupViewer;
@@ -37,6 +41,11 @@ namespace Akonadi {
   class StandardContactActionManager;
 }
 
+namespace KAddressBookGrantlee {
+class GrantleeContactFormatter;
+class GrantleeContactGroupFormatter;
+}
+
 class ContactSwitcher;
 class KActionCollection;
 class KXMLGUIClient;
@@ -78,7 +87,11 @@ class KADDRESSBOOK_EXPORT MainWidget : public QWidget
     void restoreState();
     void saveState();
 
+    void slotGrantleeThemeSelected();
+    void slotGrantleeThemesUpdated();
+
   private:
+    void initGrantleeThemeName();
     void setupGui();
     void setupActions( KActionCollection * );
     bool showQRCodes();
@@ -120,6 +133,9 @@ class KADDRESSBOOK_EXPORT MainWidget : public QWidget
     XXPortManager *mXXPortManager;
     ModelColumnManager *mModelColumnManager;
     KXMLGUIClient *mXmlGuiClient;
+    KAddressBookGrantlee::GrantleeContactFormatter *mFormatter;
+    KAddressBookGrantlee::GrantleeContactGroupFormatter *mGroupFormatter;
+    GrantleeTheme::GrantleeThemeManager *mGrantleeThemeManager;
 };
 
 #endif
