@@ -233,8 +233,7 @@ void EditAlarmDlg::init(const KAEvent* event, GetResourceType getResource)
 
 void EditAlarmDlg::init(const KAEvent* event)
 {
-    setAttribute(Qt::WA_DeleteOnClose);
-    setObjectName(mTemplate ? "TemplEditDlg" : "EditDlg");    // used by LikeBack
+    setObjectName(mTemplate ? QLatin1String("TemplEditDlg") : QLatin1String("EditDlg"));    // used by LikeBack
     QString caption;
     if (mReadOnly)
         caption = mTemplate ? i18nc("@title:window", "Alarm Template [read-only]")
@@ -1296,7 +1295,7 @@ void EditAlarmDlg::slotEditDeferral()
     // deletion of EditAlarmDlg, and on return from this function).
     AutoQPointer<DeferAlarmDlg> deferDlg = new DeferAlarmDlg((deferred ? mDeferDateTime : DateTime(now.addSecs(60).toTimeSpec(start.timeSpec()))),
                                                              start.isDateOnly(), deferred, this);
-    deferDlg->setObjectName("EditDeferDlg");    // used by LikeBack
+    deferDlg->setObjectName(QLatin1String("EditDeferDlg"));    // used by LikeBack
     if (limit)
     {
         // Don't allow deferral past the next recurrence
