@@ -477,7 +477,7 @@ void ResourceSelector::removeResource()
     QString text = std ? i18nc("@info", "Do you really want to remove your default calendar (<resource>%1</resource>) from the list?", name)
                        : i18nc("@info", "Do you really want to remove the calendar <resource>%1</resource> from the list?", name);
 #endif
-    if (KAMessageBox::warningContinueCancel(this, text, "", KStandardGuiItem::remove()) == KMessageBox::Cancel)
+    if (KAMessageBox::warningContinueCancel(this, text, QString(), KStandardGuiItem::remove()) == KMessageBox::Cancel)
         return;
 
 #ifdef USE_AKONADI
@@ -512,24 +512,24 @@ void ResourceSelector::selectionChanged()
 */
 void ResourceSelector::initActions(KActionCollection* actions)
 {
-    mActionReload      = new KAction(KIcon("view-refresh"), i18nc("@action Reload calendar", "Re&load"), this);
+    mActionReload      = new KAction(KIcon(QLatin1String("view-refresh")), i18nc("@action Reload calendar", "Re&load"), this);
     actions->addAction(QLatin1String("resReload"), mActionReload);
     connect(mActionReload, SIGNAL(triggered(bool)), SLOT(reloadResource()));
 #ifndef USE_AKONADI
-    mActionSave        = new KAction(KIcon("document-save"), i18nc("@action", "&Save"), this);
+    mActionSave        = new KAction(KIcon(QLatin1String("document-save")), i18nc("@action", "&Save"), this);
     actions->addAction(QLatin1String("resSave"), mActionSave);
     connect(mActionSave, SIGNAL(triggered(bool)), SLOT(saveResource()));
 #endif
-    mActionShowDetails = new KAction(KIcon("help-about"), i18nc("@action", "Show &Details"), this);
+    mActionShowDetails = new KAction(KIcon(QLatin1String("help-about")), i18nc("@action", "Show &Details"), this);
     actions->addAction(QLatin1String("resDetails"), mActionShowDetails);
     connect(mActionShowDetails, SIGNAL(triggered(bool)), SLOT(showInfo()));
-    mActionSetColour   = new KAction(KIcon("color-picker"), i18nc("@action", "Set &Color..."), this);
+    mActionSetColour   = new KAction(KIcon(QLatin1String("color-picker")), i18nc("@action", "Set &Color..."), this);
     actions->addAction(QLatin1String("resSetColour"), mActionSetColour);
     connect(mActionSetColour, SIGNAL(triggered(bool)), SLOT(setColour()));
     mActionClearColour   = new KAction(i18nc("@action", "Clear C&olor"), this);
     actions->addAction(QLatin1String("resClearColour"), mActionClearColour);
     connect(mActionClearColour, SIGNAL(triggered(bool)), SLOT(clearColour()));
-    mActionEdit        = new KAction(KIcon("document-properties"), i18nc("@action", "&Edit..."), this);
+    mActionEdit        = new KAction(KIcon(QLatin1String("document-properties")), i18nc("@action", "&Edit..."), this);
     actions->addAction(QLatin1String("resEdit"), mActionEdit);
     connect(mActionEdit, SIGNAL(triggered(bool)), SLOT(editResource()));
 #ifdef USE_AKONADI
@@ -537,13 +537,13 @@ void ResourceSelector::initActions(KActionCollection* actions)
     actions->addAction(QLatin1String("resUpdate"), mActionUpdate);
     connect(mActionUpdate, SIGNAL(triggered(bool)), SLOT(updateResource()));
 #endif
-    mActionRemove      = new KAction(KIcon("edit-delete"), i18nc("@action", "&Remove"), this);
+    mActionRemove      = new KAction(KIcon(QLatin1String("edit-delete")), i18nc("@action", "&Remove"), this);
     actions->addAction(QLatin1String("resRemove"), mActionRemove);
     connect(mActionRemove, SIGNAL(triggered(bool)), SLOT(removeResource()));
     mActionSetDefault  = new KToggleAction(this);
     actions->addAction(QLatin1String("resDefault"), mActionSetDefault);
     connect(mActionSetDefault, SIGNAL(triggered(bool)), SLOT(setStandard()));
-    QAction* action    = new KAction(KIcon("document-new"), i18nc("@action", "&Add..."), this);
+    QAction* action    = new KAction(KIcon(QLatin1String("document-new")), i18nc("@action", "&Add..."), this);
     actions->addAction(QLatin1String("resAdd"), action);
     connect(action, SIGNAL(triggered(bool)), SLOT(addResource()));
     mActionImport      = new KAction(i18nc("@action", "Im&port..."), this);
