@@ -246,7 +246,7 @@ void GnuPGProcessCommand::doStart() {
         d->finished();
     } else {
         d->ensureDialogVisible();
-        d->message( i18n("Starting %1...", d->arguments.join(" ") ) );
+        d->message( i18n("Starting %1...", d->arguments.join(QLatin1String(" ")) ) );
     }
 }
 
