@@ -185,9 +185,10 @@ void EncryptEMailTask::cancel() {
 std::auto_ptr<Kleo::EncryptJob> EncryptEMailTask::Private::createJob( GpgME::Protocol proto ) {
     const CryptoBackend::Protocol * const backend = CryptoBackendFactory::instance()->protocol( proto );
     kleo_assert( backend );
-    std::auto_ptr<Kleo::EncryptJob> encryptJob( backend->encryptJob( /*armor=*/proto == OpenPGP || q->asciiArmor(), /*textmode=*/false ) );
+    bool shouldArmor = ( proto == OpenPGP || q->asciiArmor() ) && !output->binaryOpt();
+    std::auto_ptr<Kleo::EncryptJob> encryptJob( backend->encryptJob( shouldArmor, /*textmode=*/false ) );
     kleo_assert( encryptJob.get() );
-    if ( proto == CMS && !q->asciiArmor() )
+    if ( proto == CMS && !q->asciiArmor() && !output->binaryOpt() )
         encryptJob->setOutputIsBase64Encoded( true );
     connect( encryptJob.get(), SIGNAL(progress(QString,int,int)),
              q, SLOT(setProgress(QString,int,int)) );
