@@ -66,6 +66,7 @@ namespace KMail {
   class StatusBarLabel;
   class TagActionManager;
   class FolderShortcutActionManager;
+  class VacationManager;
 }
 
 namespace KSieveUi {
@@ -117,7 +118,7 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
     QSharedPointer<MailCommon::FolderCollection> currentFolder() const;
 
     static void cleanup();
-    QAction *action( const char *name ) { return mActionCollection->action( name ); }
+    QAction *action( const QString &name ) { return mActionCollection->action( name ); }
     KActionMenu *filterMenu() const { return mFilterMenu; }
     KActionMenu *mailingListActionMenu() const { return mMsgActions->mailingListActionMenu(); }
     KAction *editAction() const { return mMsgActions->editAction(); }
@@ -412,7 +413,7 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
     */
     void showOfflinePage();
     void showResourceOfflinePage();
-    void updateVacationScriptStatus( bool active );
+    void updateVacationScriptStatus(bool active , const QString &serverName = QString());
 
 
     void slotShowExpiryProperties();
@@ -430,6 +431,7 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
     void slotCreateAddressBookContact();
     void slotOpenRecentMsg(const KUrl& url);
     void slotConfigureSendLater();
+    void slotConfigureFolderArchiving();
 
   private:
     void checkAkonadiServerManagerState();
@@ -524,6 +526,7 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
 
     void itemsReceived(const Akonadi::Item::List &list );
     void itemsFetchDone( KJob *job );
+    void itemsFetchForActivationDone( KJob *job );
 
     void slotCollectionPropertiesContinued( KJob* job );
     void slotCollectionPropertiesFinished( KJob *job );
@@ -532,6 +535,7 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
     void slotFetchItemsForFolderDone(KJob*job);
     void slotServerStateChanged(Akonadi::ServerManager::State state);
     void slotConfigureSubscriptionFinished(QDBusPendingCallWatcher* watcher);
+    void slotArchiveMails();
 private:
     // Message actions
     KAction *mDeleteAction, *mTrashThreadAction,
@@ -539,6 +543,7 @@ private:
       *mSendAgainAction, *mApplyAllFiltersAction,
       *mSaveAttachmentsAction, *mOpenAction,
       *mMoveMsgToFolderAction, *mCollectionProperties, *mSendQueued;
+    KAction *mArchiveAction;
     KActionMenu *mSendActionMenu;
     // Filter actions
     KActionMenu *mFilterMenu;
@@ -585,15 +590,14 @@ private:
     QTimer *menutimer;
     QTimer *mShowBusySplashTimer;
 
-    QPointer<KSieveUi::Vacation> mVacation;
-    QPointer<KSieveUi::Vacation> mCheckVacation;
+    KMail::VacationManager *mVacationManager;
 #if !defined(NDEBUG)
     QPointer<KSieveUi::SieveDebugDialog> mSieveDebugDialog;
 #endif
     KActionCollection *mActionCollection;
     QAction *mToolbarActionSeparator;
     QVBoxLayout *mTopLayout;
-    bool mDestructed, mShowingOfflineScreen;
+    bool mDestructed;
     QList<QAction*> mFilterMenuActions;
     QList<QAction*> mFilterTBarActions;
     QList<KMMetaFilterActionCommand*> mFilterCommands;
