@@ -1,6 +1,7 @@
 /* -*- mode: C++; c-file-style: "gnu" -*-
   This file is part of KMail, the KDE mail client.
   Copyright (c) 1997 Markus Wuebben <markus.wuebben@kde.org>
+  Copyright (c) 2013 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -25,9 +26,11 @@
 #include <messageviewer/viewer/viewer.h>
 #include <messageviewer/interfaces/bodypart.h>
 #include <Akonadi/Item>
+#include <KABC/Addressee>
 class KActionCollection;
 class KAction;
 class KToggleAction;
+class KMenu;
 namespace MessageViewer {
   class HeaderStrategy;
   class HeaderStyle;
@@ -126,30 +129,36 @@ public:
   bool isFixedFont() const;
   void setUseFixedFont( bool useFixedFont );
   MessageViewer::Viewer *viewer() { return mViewer; }
-  KToggleAction *toggleFixFontAction();
-  KAction *mailToComposeAction() { return mMailToComposeAction; }
-  KAction *mailToReplyAction() { return mMailToReplyAction; }
-  KAction *mailToForwardAction() { return mMailToForwardAction; }
-  KAction *addAddrBookAction() { return mAddAddrBookAction; }
-  KAction *openAddrBookAction() { return mOpenAddrBookAction; }
-  KAction *copyAction();
-  KAction *selectAllAction();
-  KAction *copyURLAction();
-  KAction *copyImageLocation();
-  KAction *urlOpenAction();
-  KAction *urlSaveAsAction() { return mUrlSaveAsAction; }
-  KAction *addBookmarksAction() { return mAddBookmarksAction;}
-  KAction *toggleMimePartTreeAction();
-  KAction *speakTextAction();
-  KAction* translateAction();
+  KToggleAction *toggleFixFontAction() const;
+  KAction *mailToComposeAction() const { return mMailToComposeAction; }
+  KAction *mailToReplyAction() const { return mMailToReplyAction; }
+  KAction *mailToForwardAction() const { return mMailToForwardAction; }
+  KAction *addAddrBookAction() const { return mAddAddrBookAction; }
+  KAction *openAddrBookAction() const { return mOpenAddrBookAction; }
+  KAction *copyAction() const;
+  KAction *selectAllAction() const;
+  KAction *copyURLAction() const;
+  KAction *copyImageLocation() const;
+  KAction *urlOpenAction() const;
+  KAction *urlSaveAsAction() const { return mUrlSaveAsAction; }
+  KAction *addBookmarksAction() const { return mAddBookmarksAction;}
+  KAction *toggleMimePartTreeAction() const;
+  KAction *speakTextAction() const;
+  KAction* translateAction() const;
   KAction* downloadImageToDiskAction() const;
-  KAction *viewSourceAction();
-  KAction *findInMessageAction();
-  KAction *saveAsAction();
-  KAction *saveMessageDisplayFormatAction();
-  KAction *resetMessageDisplayFormatAction();
+  KAction *viewSourceAction() const;
+  KAction *findInMessageAction() const;
+  KAction *saveAsAction() const;
+  KAction *saveMessageDisplayFormatAction() const;
+  KAction *resetMessageDisplayFormatAction() const;
+  KAction *blockImage() const;
+  KAction *openBlockableItems() const;
+  KAction *expandShortUrlAction() const;
 
-  KAction* editContactAction() const { return mEditContactAction; }
+  KAction *editContactAction() const { return mEditContactAction; }
+
+  KMenu *viewHtmlOption() const { return mViewHtmlOptions; }
+  KAction *shareImage() const { return mShareImage; }
 
   Akonadi::Item message() const;
 
@@ -162,7 +171,10 @@ public:
 
   bool printSelectedText(bool preview);
 
-  void setContactItem(const Akonadi::Item& contact);
+  void setContactItem(const Akonadi::Item& contact, const KABC::Addressee &address);
+  void clearContactItem();
+  bool adblockEnabled() const;
+  bool isAShortUrl(const KUrl &url) const;
 
 signals:
   /** Emitted after parsing of a message to have it stored
@@ -199,23 +211,39 @@ public slots:
   void contactStored( const Akonadi::Item &item );
   void slotContactEditorError(const QString &error);
 
-protected:
+  void slotContactHtmlOptions();
+  void slotShareImage();
 
+protected:
   KUrl urlClicked() const;
   KUrl imageUrlClicked() const;
 
 private:
   void createActions();
+  void updateHtmlActions();
+
 private:
+  KABC::Addressee mSearchedAddress;
   Akonadi::Item mSearchedContact;
   QWidget *mMainWindow;
   KActionCollection *mActionCollection;
 
-  KAction *mMailToComposeAction, *mMailToReplyAction, *mMailToForwardAction,
-    *mAddAddrBookAction, *mOpenAddrBookAction, *mUrlSaveAsAction, *mAddBookmarksAction,*mImageUrlSaveAsAction, *mEditContactAction;
+  KAction *mMailToComposeAction;
+  KAction *mMailToReplyAction;
+  KAction *mMailToForwardAction;
+  KAction *mAddAddrBookAction;
+  KAction *mOpenAddrBookAction;
+  KAction *mUrlSaveAsAction;
+  KAction *mAddBookmarksAction;
+  KAction *mImageUrlSaveAsAction;
+  KAction *mEditContactAction;
+  KAction *mViewAsHtml;
+  KAction *mLoadExternalReference;
+  KAction *mShareImage;
+
+  KMenu *mViewHtmlOptions;
 
   MessageViewer::Viewer *mViewer;
-
 };
 
 
