@@ -57,7 +57,8 @@ void checkConfigUpdates() {
     "3.5.7-imap-flag-migration",
     "4.0-misc",
     "4.2",
-    "4.4-akonadi"
+    "4.4-akonadi",
+    "4.12"
   };
   static const int numUpdates = sizeof updates / sizeof *updates;
   // Warning: do not remove entries in the above array, or the update-level check below will break
@@ -68,7 +69,7 @@ void checkConfigUpdates() {
     return;
 
   for ( int i = configUpdateLevel ; i < numUpdates ; ++i ) {
-    config->checkUpdate( updates[i], "kmail.upd" );
+    config->checkUpdate( QLatin1String(updates[i]), QLatin1String("kmail.upd") );
   }
   GlobalSettings::self()->setUpdateLevel( numUpdates );
 }
@@ -94,15 +95,15 @@ void insertLibraryCataloguesAndIcons() {
     "libkpimutils",
     "akonadicontact",
     "kabc",
-    "akonadi_sendlater_agent"
-
+    "akonadi_sendlater_agent",
+    "akonadi_folderagent_agent"
   };
 
   KLocale * l = KGlobal::locale();
   KIconLoader * il = KIconLoader::global();
   for ( unsigned int i = 0 ; i < sizeof catalogs / sizeof *catalogs ; ++i ) {
-    l->insertCatalog( catalogs[i] );
-    il->addAppDir( catalogs[i] );
+    l->insertCatalog( QLatin1String(catalogs[i]) );
+    il->addAppDir( QLatin1String(catalogs[i]) );
   }
 
 }
