@@ -44,9 +44,9 @@
 #include <kxmlguifactory.h>
 #include <ksqueezedtextlabel.h>
 
-#include "libkdepim/uistatesaver.h"
-#include "libkdepim/broadcaststatus.h"
-#include "libkdepim/recentaddresses.h"
+#include "libkdepim/misc/uistatesaver.h"
+#include "libkdepim/misc/broadcaststatus.h"
+#include "libkdepim/addressline/recentaddresses.h"
 using KPIM::BroadcastStatus;
 using KPIM::RecentAddresses;
 
