@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,13 +18,21 @@
 #ifndef KNOTEUTILS_H
 #define KNOTEUTILS_H
 #include "knotes_export.h"
-#include <Akonadi/Item>
+
+class QWidget;
+class KNoteConfig;
+namespace KCal {
+class Journal;
+}
 
 namespace KNoteUtils
 {
-KNOTES_EXPORT void migrateToAkonadi();
-KNOTES_EXPORT void setDefaultValue(Akonadi::Item &item);
-KNOTES_EXPORT void updateConfiguration();
+KNOTES_EXPORT KNoteConfig *createConfig(KCal::Journal *journal, QString &configPath);
+KNOTES_EXPORT void setProperty(KCal::Journal *journal, KNoteConfig *config);
+KNOTES_EXPORT void removeNote(KCal::Journal *journal, QWidget *parent);
+KNOTES_EXPORT void savePreferences( KCal::Journal *journal, KNoteConfig *config);
+KNOTES_EXPORT void sendMail(QWidget *parent, const QString &title, const QString &message);
+KNOTES_EXPORT void sendToNetwork(QWidget *parent, const QString &title, const QString &message);
 }
 
 #endif // KNOTEUTILS_H
