@@ -29,49 +29,37 @@
 #include <KontactInterface/Summary>
 
 namespace KCal {
-  class CalendarLocal;
+class CalendarLocal;
 }
 using namespace KCal;
 
-namespace KontactInterface {
-  class Plugin;
-}
-
-class KNotesResourceManager;
+class KNotesPlugin;
 class QGridLayout;
 class QLabel;
 
 class KNotesSummaryWidget : public KontactInterface::Summary
 {
-  Q_OBJECT
-  public:
-    KNotesSummaryWidget( KontactInterface::Plugin *plugin, QWidget *parent );
+    Q_OBJECT
+public:
+    KNotesSummaryWidget(KCal::CalendarLocal *calendar, KNotesPlugin *plugin, QWidget *parent );
     ~KNotesSummaryWidget();
 
-    void updateSummary( bool force = false )
-    {
-      Q_UNUSED( force );
-      updateView();
-    }
+    void updateSummary( bool force = false );
 
-  protected:
+protected:
     virtual bool eventFilter( QObject *obj, QEvent *e );
 
-  protected slots:
+protected slots:
     void urlClicked( const QString & );
     void updateView();
-    void addNote( KCal::Journal * );
-    void removeNote( KCal::Journal * );
-
-  private:
-    CalendarLocal *mCalendar;
-    Journal::List mNotes;
 
+private:
     QGridLayout *mLayout;
 
     QList<QLabel *> mLabels;
-    KontactInterface::Plugin *mPlugin;
-    KNotesResourceManager *mManager;
+    KNotesPlugin *mPlugin;
+    QPixmap mPixmap;
+    KCal::CalendarLocal *mCalendar;
 };
 
 #endif
