@@ -83,21 +83,7 @@ class KORGANIZERPRIVATE_EXPORT ActionManager : public QObject
     void createCalendarAkonadi();
 
   public slots:
-
-    /** Add a new resource
-        @param mUrl The url for the new resource. Either a local or a remote
-                    resource will be added, depending on the type of the url.
-    */
-    bool addResource( const KUrl &mUrl );
-
-    /**
-      Open calendar file from URL. Merge into current calendar, if \a merge is true.
-        @param url The URL to open
-        @param merge If true, the items from the url will be inserted into the
-                     current calendar (default resource). Otherwise a new
-                     resource is added for the given url.
-    */
-    bool openURL( const KUrl &url, bool merge = false );
+    bool importURL( const KUrl &url, bool merge);
 
     /** Save calendar file to URL of current calendar */
     bool saveURL();
@@ -136,9 +122,6 @@ class KORGANIZERPRIVATE_EXPORT ActionManager : public QObject
     /** Save calendar file to URL */
     bool saveAsURL( const QString &url );
 
-    /** Close calendar file opened from URL */
-    void closeUrl();
-
     /** Get current URL as QString */
     QString getCurrentURLasString() const;
 
@@ -247,12 +230,6 @@ class KORGANIZERPRIVATE_EXPORT ActionManager : public QObject
     */
     void configChanged();
 
-    /**
-      Emitted when the topwidget is closing down, so that any attached
-      child windows can also close.
-    */
-    void closingDown();
-
   public slots:
     /**
       Options dialog made a changed to the configuration. we catch this
@@ -309,9 +286,6 @@ class KORGANIZERPRIVATE_EXPORT ActionManager : public QObject
     /** delete or archive old entries in your calendar for speed/space. */
     void file_archive();
 
-    /** close a file, prompt for save if changes made. */
-    void file_close();
-
     /** Open kcontrol module for configuring date and time formats */
     void configureDateTime();
 
@@ -338,14 +312,10 @@ class KORGANIZERPRIVATE_EXPORT ActionManager : public QObject
 
     void updateUndoRedoActions();
 
-    void agentCreated( KJob * );
-
   protected:
     /** Get URL for saving. Opens FileDialog. */
     KUrl getSaveURL();
 
-    void showStatusMessageOpen( bool merge );
-
     /**
       Return widget used as parent for dialogs and message boxes.
     */
@@ -362,6 +332,11 @@ class KORGANIZERPRIVATE_EXPORT ActionManager : public QObject
     void slotNewTodo();
     void slotNewSubTodo();
     void slotNewJournal();
+
+    void slotMergeFinished(bool success, int total);
+    void slotNewResourceFinished(bool);
+
+
   private:
     class ActionStringsVisitor;
 
@@ -392,6 +367,8 @@ class KORGANIZERPRIVATE_EXPORT ActionManager : public QObject
 
     KToggleAction *mHideMenuBarAction;
 
+    KAction *mImportAction;
+
     KAction *mNewEventAction;
     KAction *mNewTodoAction;
     KAction *mNewSubtodoAction;
