@@ -56,7 +56,7 @@ KOrganizer::KOrganizer() : KParts::MainWindow(), KOrg::MainWindow()
 //  setMinimumSize(600,400);  // make sure we don't get resized too small...
 
   mCalendarView = new CalendarView( this );
-  mCalendarView->setObjectName( "KOrganizer::CalendarView" );
+  mCalendarView->setObjectName( QLatin1String("KOrganizer::CalendarView") );
   setCentralWidget( mCalendarView );
 
   mActionManager = new ActionManager( this, mCalendarView, this, this, false, menuBar() );
@@ -91,7 +91,7 @@ void KOrganizer::init( bool document )
 
   KStatusBar *bar = statusBar();
 
-  bar->insertItem( "", ID_GENERAL, 10 );
+  bar->insertItem( QString(), ID_GENERAL, 10 );
   connect( bar, SIGNAL(pressed(int)), SLOT(statusBarPressed(int)) );
 
   KPIM::ProgressDialog *progressDialog = new KPIM::ProgressDialog( bar, this );
@@ -115,7 +115,7 @@ void KOrganizer::newMainWindow( const KUrl &url )
   KOrganizer *korg = new KOrganizer();
   if ( url.isValid() || url.isEmpty() ) {
     korg->init( true );
-    if ( korg->openURL( url ) || url.isEmpty() ) {
+    if ( mActionManager->importURL( url, false ) || url.isEmpty() ) {
       korg->show();
     } else {
       delete korg;
@@ -157,7 +157,7 @@ void KOrganizer::initActions()
   KStandardAction::configureToolbars( this, SLOT(configureToolbars()), actionCollection() );
   KStandardAction::quit( this, SLOT(close()), actionCollection() );
 
-  setXMLFile( "korganizerui.rc", true );
+  setXMLFile( QLatin1String("korganizerui.rc"), true );
   createGUI( 0 );
 
   setAutoSaveSettings();
@@ -204,7 +204,7 @@ void KOrganizer::showStatusMessage( const QString &message )
 
 bool KOrganizer::openURL( const KUrl &url, bool merge )
 {
-  return mActionManager->openURL( url, merge );
+  return mActionManager->importURL( url, merge );
 }
 
 bool KOrganizer::saveURL()
@@ -256,11 +256,11 @@ void KOrganizer::setTitle()
     }
 
     if ( mCalendarView->isReadOnly() ) {
-      title += " [" + i18nc( "the calendar is read-only", "read-only" ) + ']';
+      title += QLatin1String(" [") + i18nc( "the calendar is read-only", "read-only" ) + QLatin1Char(']');
     }
   }
   if ( mCalendarView->isFiltered() ) {
-    title += " - <" + mCalendarView->currentFilterName() + "> ";
+    title += QLatin1String(" - <") + mCalendarView->currentFilterName() + QLatin1String("> ");
   }
 
   setCaption( title, false );
