@@ -126,7 +126,7 @@ class AddresseeLineEditStatic
       int clientIndex = 0;
       foreach ( const KLDAP::LdapClient *client, ldapSearch->clients() ) {
         const int sourceIndex =
-          addCompletionSource( QLatin1String( "LDAP server: " ) + client->server().host(),
+          addCompletionSource( i18n( "LDAP server: %1" ,client->server().host()),
                                   client->completionWeight() );
 
         ldapClientToCompletionSourceMap.insert( clientIndex, sourceIndex );
@@ -153,6 +153,15 @@ class AddresseeLineEditStatic
       }
     }
 
+    void removeCompletionSource( const QString &source )
+    {
+        QMap<QString,int>::iterator it = completionSourceWeights.find( source );
+        if ( it != completionSourceWeights.end() ) {
+            completionSourceWeights.remove(source);
+            completion->clear();
+        }
+    }
+
     KMailCompletion *completion;
     KPIM::CompletionItemsMap completionItemMap;
     QStringList completionSources;
@@ -1420,6 +1429,11 @@ QMenu *AddresseeLineEdit::createStandardContextMenu()
 }
 #endif
 
+void KPIM::AddresseeLineEdit::removeCompletionSource(const QString &source)
+{
+    s_static->removeCompletionSource(source);
+}
+
 int KPIM::AddresseeLineEdit::addCompletionSource( const QString &source, int weight )
 {
     return s_static->addCompletionSource(source,weight);
