@@ -152,7 +152,7 @@ class StatisticsProxyModel::Private
 
       QString iconPath;
 
-      for ( int i = 0; i < 2; i++ ) {
+      for ( int i = 0; i < 2; ++i ) {
         iconPath = KIconLoader::global()->iconPath( iconName, -iconSizes[ i ], true );
         if ( !iconPath.isEmpty() ) {
           icon_size_found = iconSizes[ i ];
