@@ -25,6 +25,8 @@
 
 #include <QLabel>
 #include <QHBoxLayout>
+#include <QDomNode>
+#include <QDebug>
 
 using namespace KSieveUi;
 SieveActionEnclose::SieveActionEnclose(QObject *parent)
@@ -37,38 +39,79 @@ SieveAction* SieveActionEnclose::newAction()
     return new SieveActionEnclose;
 }
 
-
 QWidget *SieveActionEnclose::createParamWidget( QWidget *parent ) const
 {
     QWidget *w = new QWidget(parent);
-    QHBoxLayout *lay = new QHBoxLayout;
-    lay->setMargin(0);
-    w->setLayout(lay);
+    QGridLayout *grid = new QGridLayout;
+    grid->setMargin(0);
+    w->setLayout(grid);
 
     QLabel *lab = new QLabel(i18n("Subject:"));
-    lay->addWidget(lab);
+    grid->addWidget(lab,0,0);
 
     KLineEdit *subject = new KLineEdit;
     subject->setObjectName(QLatin1String("subject"));
-    lay->addWidget(subject);
+    grid->addWidget(subject,0,1);
 
     lab = new QLabel(i18n("headers:"));
-    lay->addWidget(lab);
+    grid->addWidget(lab,1,0);
 
     KLineEdit *headers = new KLineEdit;
     headers->setObjectName(QLatin1String("headers"));
-    lay->addWidget(headers);
+    grid->addWidget(headers,1,1);
 
     lab = new QLabel(i18n("text:"));
-    lay->addWidget(lab);
+    grid->addWidget(lab,2,0);
 
     MultiLineEdit *text = new MultiLineEdit;
     text->setObjectName(QLatin1String("text"));
-    lay->addWidget(text);
+    grid->addWidget(text,2,1);
 
     return w;
 }
 
+bool SieveActionEnclose::setParamWidgetValue(const QDomElement &element, QWidget *w, QString &error )
+{
+    QDomNode node = element.firstChild();
+    while (!node.isNull()) {
+        QDomElement e = node.toElement();
+        if (!e.isNull()) {
+            const QString tagName = e.tagName();
+            if (tagName == QLatin1String("tag")) {
+                const QString tagValue = e.text();
+                if (tagValue == QLatin1String("headers")) {
+                    const QString strValue = AutoCreateScriptUtil::strValue(node);
+                    if (!strValue.isEmpty()) {
+                        KLineEdit *subject = w->findChild<KLineEdit*>(QLatin1String("subject"));
+                        subject->setText(strValue);
+                    }
+                } else if (tagValue == QLatin1String("subject")) {
+                    const QString strValue = AutoCreateScriptUtil::strValue(node);
+                    if (!strValue.isEmpty()) {
+                        KLineEdit *headers = w->findChild<KLineEdit*>(QLatin1String("headers"));
+                        headers->setText(strValue);
+                    }
+                } else {
+                    unknowTagValue(tagValue, error);
+                    qDebug()<<" SieveActionEnclose::setParamWidgetValue unknown tag value:"<<tagValue;
+                }
+            } else if (tagName == QLatin1String("str")) {
+                MultiLineEdit *edit = w->findChild<MultiLineEdit*>( QLatin1String("text") );
+                edit->setText(e.text());
+            } else if (tagName == QLatin1String("crlf")) {
+                //nothing
+            } else if (tagName == QLatin1String("comment")) {
+                //implement in the future ?
+            } else {
+                unknownTag(tagName, error);
+                qDebug()<<" SieveActionEnclose::setParamWidgetValue unknown tagName "<<tagName;
+            }
+        }
+        node = node.nextSibling();
+    }
+    return true;
+}
+
 QString SieveActionEnclose::code(QWidget *w) const
 {
     QString result = QLatin1String("enclose ");
@@ -84,18 +127,19 @@ QString SieveActionEnclose::code(QWidget *w) const
         result += QString::fromLatin1(":headers \"%1\" ").arg(headersStr);
     }
 
-
     const MultiLineEdit *edit = w->findChild<MultiLineEdit*>( QLatin1String("text") );
     const QString text = edit->toPlainText();
     if (!text.isEmpty()) {
         result += QString::fromLatin1("text:%1").arg(AutoCreateScriptUtil::createMultiLine(text));
+    } else {
+        result += QLatin1Char(';');
     }
 
     return result;
 }
 
 
-QStringList SieveActionEnclose::needRequires(QWidget *parent) const
+QStringList SieveActionEnclose::needRequires(QWidget */*parent*/) const
 {
     return QStringList() << QLatin1String("enclose");
 }
