@@ -33,7 +33,9 @@ public:
     QString code(QWidget *) const;
     QString serverNeedsCapability() const;
     bool needCheckIfServerHasCapability() const;
+    bool setParamWidgetValue(const QDomElement &element, QWidget *parent, QString &error );
     QString help() const;
+    QStringList needRequires(QWidget *) const;
 };
 }
 
