@@ -25,6 +25,8 @@ class KPushButton;
 class KLineEdit;
 class QGridLayout;
 class QCheckBox;
+class QDomElement;
+
 namespace KSieveUi {
 class SieveGlobalVariableWidget;
 
@@ -37,6 +39,10 @@ public:
 
     void generatedScript(QString &script);
     void updateAddRemoveButton( bool addButtonEnabled, bool removeButtonEnabled );
+    bool isInitialized() const;
+    void loadScript(const QDomElement &element, QString &error);
+    void setVariableValue(const QString &name);
+    QString variableName() const;
 
 private Q_SLOTS:
     void slotAddWidget();
@@ -64,6 +70,9 @@ public:
     ~SieveGlobalVariableLister();
 
     void generatedScript(QString &script, QStringList &requires);
+    void loadScript(const QDomElement &element, QString &error);
+    void loadSetVariable(const QDomElement &element, QString &error);
+
 public Q_SLOTS:
     void slotAddWidget( QWidget *w );
     void slotRemoveWidget( QWidget *w );
@@ -86,6 +95,9 @@ public:
 
     void generatedScript(QString &script, QStringList &requires);
 
+    void loadScript(const QDomElement &element, QString &error);
+    void loadSetVariable(const QDomElement &element, QString &error);
+
 private Q_SLOTS:
     void slotHelp();
 
@@ -94,11 +106,4 @@ private:
 };
 }
 
-
-class SieveGlobalVariableWidget
-{
-public:
-    SieveGlobalVariableWidget();
-};
-
 #endif // SIEVEGLOBALVARIABLEWIDGET_H
