@@ -25,6 +25,7 @@ class QGroupBox;
 class QAbstractButton;
 class KComboBox;
 class KPushButton;
+class QDomElement;
 
 namespace KSieveUi {
 class SieveConditionWidgetLister;
@@ -49,6 +50,8 @@ public:
 
     MatchCondition matchCondition() const;
 
+    void loadScript(const QDomElement &element, bool onlyActions, QString &error);
+
 Q_SIGNALS:
     void addNewBlock(QWidget *widget, KSieveUi::SieveWidgetPageAbstract::PageType type);
 
@@ -57,6 +60,8 @@ private Q_SLOTS:
     void slotAddBlock();
 
 private:
+    void updateWidget();
+    void updateCondition();
     MatchCondition mMatchCondition;
     QGroupBox *mConditions;
     SieveConditionWidgetLister *mScriptConditionLister;
