@@ -20,14 +20,15 @@
 
 #include <KDialog>
 
-class KTextEdit;
-
+namespace PimCommon {
+class RichTextEditorWidget;
+}
 namespace KSieveUi {
 class SieveScriptDescriptionDialog : public KDialog
 {
     Q_OBJECT
 public:
-    explicit SieveScriptDescriptionDialog(QWidget *parent);
+    explicit SieveScriptDescriptionDialog(QWidget *parent=0);
     ~SieveScriptDescriptionDialog();
 
     void setDescription(const QString &desc);
@@ -38,7 +39,7 @@ private:
     void writeConfig();
 
 private:
-    KTextEdit *mEdit;
+    PimCommon::RichTextEditorWidget *mEdit;
 };
 }
 
