@@ -1,5 +1,22 @@
+/*
+  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+
+  This program is free software; you can redistribute it and/or modify it
+  under the terms of the GNU General Public License, version 2, as
+  published by the Free Software Foundation.
+
+  This program is distributed in the hope that it will be useful, but
+  WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  General Public License for more details.
+
+  You should have received a copy of the GNU General Public License along
+  with this program; if not, write to the Free Software Foundation, Inc.,
+  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+*/
 
 #include "managesievescriptsdialog.h"
+#include "widgets/managesievetreeview.h"
 #include "editor/sievetextedit.h"
 #include "editor/sieveeditor.h"
 #include "widgets/sievetreewidgetitem.h"
@@ -8,80 +25,23 @@
 #include <kiconloader.h>
 #include <kwindowsystem.h>
 #include <kinputdialog.h>
-#include <kglobalsettings.h>
 #include <kpushbutton.h>
 #include <kmessagebox.h>
 
 #include <akonadi/agentinstance.h>
 #include <kmanagesieve/sievejob.h>
-#include <ksieveui/util.h>
+#include <ksieveui/util/util.h>
 
 #include <QApplication>
-#include <QButtonGroup>
 #include <QMenu>
 #include <QTreeWidget>
 #include <QVBoxLayout>
 #include <QDebug>
-#include <QPainter>
 
 #include <errno.h>
 
 using namespace KSieveUi;
 
-ManageSieveTreeView::ManageSieveTreeView(QWidget *parent)
-    : QTreeWidget(parent),
-      mImapFound(true)
-{
-    connect( KGlobalSettings::self(), SIGNAL(kdisplayFontChanged()),
-             this, SLOT(slotGeneralFontChanged()));
-    connect( KGlobalSettings::self(), SIGNAL(kdisplayPaletteChanged()),
-             this, SLOT(slotGeneralPaletteChanged()));
-}
-
-ManageSieveTreeView::~ManageSieveTreeView()
-{
-}
-
-void ManageSieveTreeView::slotGeneralPaletteChanged()
-{
-    const QPalette palette = viewport()->palette();
-    QColor color = palette.text().color();
-    color.setAlpha( 128 );
-    mTextColor = color;
-}
-
-void ManageSieveTreeView::slotGeneralFontChanged()
-{
-    setFont( KGlobalSettings::generalFont() );
-}
-
-void ManageSieveTreeView::setImapFound(bool found)
-{
-    if (mImapFound != found) {
-        mImapFound = found;
-        update();
-    }
-}
-
-void ManageSieveTreeView::paintEvent( QPaintEvent *event )
-{
-    if ( mImapFound ) {
-        QTreeWidget::paintEvent(event);
-    } else {
-        QPainter p( viewport() );
-
-        QFont font = p.font();
-        font.setItalic( true );
-        p.setFont( font );
-
-        if (!mTextColor.isValid()) {
-            slotGeneralPaletteChanged();
-        }
-        p.setPen( mTextColor );
-
-        p.drawText( QRect( 0, 0, width(), height() ), Qt::AlignCenter, i18n( "No imap server configured..." ) );
-    }
-}
 
 ManageSieveScriptsDialog::ManageSieveScriptsDialog( QWidget * parent )
     : QDialog( parent ),
@@ -225,15 +185,14 @@ void ManageSieveScriptsDialog::slotUpdateButtons()
     }
 }
 
-
 void ManageSieveScriptsDialog::slotRefresh()
 {
     mBlockSignal = true;
     clear();
     SieveTreeWidgetItem *last = 0;
     Akonadi::AgentInstance::List lst = KSieveUi::Util::imapAgentInstances();
-    bool imapFound = false;
-    foreach ( const Akonadi::AgentInstance& type, lst ) {
+    bool noImapFound = true;
+    foreach ( const Akonadi::AgentInstance &type, lst ) {
         if ( type.status() == Akonadi::AgentInstance::Broken )
             continue;
 
@@ -249,21 +208,19 @@ void ManageSieveScriptsDialog::slotRefresh()
             mListView->expandItem( last );
         } else {
             KManageSieve::SieveJob * job = KManageSieve::SieveJob::list( u );
-            connect( job, SIGNAL(item(KManageSieve::SieveJob*,QString,bool)),
-                     this, SLOT(slotItem(KManageSieve::SieveJob*,QString,bool)) );
-            connect( job, SIGNAL(result(KManageSieve::SieveJob*,bool,QString,bool)),
-                     this, SLOT(slotResult(KManageSieve::SieveJob*,bool,QString,bool)) );
+            connect( job, SIGNAL(gotList(KManageSieve::SieveJob*,bool,QStringList,QString)),
+                     this, SLOT(slotGotList(KManageSieve::SieveJob*,bool,QStringList,QString)) );
             mJobs.insert( job, last );
             mUrls.insert( last, u );
             last->startAnimation();
         }
-        imapFound = true;
+        noImapFound = false;
     }
     slotUpdateButtons();
-    mListView->setImapFound(imapFound);
+    mListView->setNoImapFound(noImapFound);
 }
 
-void ManageSieveScriptsDialog::slotResult( KManageSieve::SieveJob *job, bool success, const QString &, bool )
+void ManageSieveScriptsDialog::slotGotList(KManageSieve::SieveJob *job, bool success, const QStringList &listScript, const QString &activeScript)
 {
     if (mClearAll)
         return;
@@ -271,41 +228,48 @@ void ManageSieveScriptsDialog::slotResult( KManageSieve::SieveJob *job, bool suc
     if ( !parent )
         return;
     (static_cast<SieveTreeWidgetItem*>(parent))->stopAnimation();
-    if (success)
-        parent->setData( 0, SIEVE_SERVER_CAPABILITIES, job->sieveCapabilities() );
+
     mJobs.remove( job );
-
-    mListView->expandItem( parent );
-
-    mBlockSignal = false;
-    if ( success )
+    if (!success) {
+        mBlockSignal = false;
+        parent->setData( 0, SIEVE_SERVER_ERROR, true );
+        QTreeWidgetItem * item =
+                new QTreeWidgetItem( parent );
+        item->setText( 0, i18n( "Failed to fetch the list of scripts" ) );
+        item->setFlags( item->flags() & ~Qt::ItemIsEnabled );
         return;
-
-    parent->setData( 0, SIEVE_SERVER_ERROR, true );
-    QTreeWidgetItem * item =
-            new QTreeWidgetItem( parent );
-    item->setText( 0, i18n( "Failed to fetch the list of scripts" ) );
-    item->setFlags( item->flags() & ~Qt::ItemIsEnabled );
-
-}
-
-void ManageSieveScriptsDialog::slotItem( KManageSieve::SieveJob * job, const QString & filename, bool isActive )
-{
-    QTreeWidgetItem * parent = mJobs[job];
-    if ( !parent )
-        return;
-    const bool oldBlockSignal = mBlockSignal;
-    mBlockSignal = true; // don't trigger slotItemChanged
-
-    QTreeWidgetItem* item = new QTreeWidgetItem( parent );
-    item->setFlags(item->flags() & (Qt::ItemIsUserCheckable|Qt::ItemIsEnabled|Qt::ItemIsSelectable));
-
-    item->setText(0,filename);
-    item->setCheckState(0, isActive ? Qt::Checked : Qt::Unchecked);
-    if ( isActive ) {
-        mSelectedItems[parent] = item;
     }
-    mBlockSignal = oldBlockSignal;
+
+
+    mBlockSignal = true; // don't trigger slotItemChanged
+    Q_FOREACH (const QString &script, listScript) {
+        //Hide protected name.
+        const QString lowerScript(script.toLower());
+        if (isProtectedName(lowerScript))
+            continue;
+        QTreeWidgetItem* item = new QTreeWidgetItem( parent );
+        item->setFlags(item->flags() & (Qt::ItemIsUserCheckable|Qt::ItemIsEnabled|Qt::ItemIsSelectable));
+
+        item->setText(0, script);
+        const bool isActive = (script == activeScript);
+        item->setCheckState(0, isActive ? Qt::Checked : Qt::Unchecked);
+        if ( isActive ) {
+            mSelectedItems[parent] = item;
+        }
+    }
+    mBlockSignal = false;
+
+    const bool hasIncludeCapability = job->sieveCapabilities().contains(QLatin1String("include"));
+    const bool hasUserActiveScript = (activeScript.toLower() == QLatin1String("USER"));
+    QStringList mUserActiveScriptList;
+    if (hasUserActiveScript && hasIncludeCapability) {
+        //TODO parse file.
+    }
+
+    parent->setData( 0, SIEVE_SERVER_CAPABILITIES, job->sieveCapabilities() );
+    parent->setData( 0, SIEVE_SERVER_ERROR, false );
+    parent->setData( 0, SIEVE_SERVER_MODE, hasIncludeCapability ? Kep14EditorMode : NormalEditorMode);
+    mListView->expandItem( parent );
 }
 
 void ManageSieveScriptsDialog::slotContextMenuRequested( const QPoint& p )
@@ -449,6 +413,17 @@ void ManageSieveScriptsDialog::slotEditScript()
              this, SLOT(slotGetResult(KManageSieve::SieveJob*,bool,QString,bool)) );
 }
 
+
+bool ManageSieveScriptsDialog::isProtectedName(const QString &name)
+{
+    if (name == QLatin1String("master") ||
+            name == QLatin1String("user") ||
+            name == QLatin1String("management")) {
+        return true;
+    }
+    return false;
+}
+
 void ManageSieveScriptsDialog::slotNewScript()
 {
     QTreeWidgetItem *currentItem = mListView->currentItem();
@@ -473,6 +448,11 @@ void ManageSieveScriptsDialog::slotNewScript()
     if ( !ok || name.isEmpty() )
         return;
 
+    if (isProtectedName(name.toLower())) {
+        KMessageBox::error(this, i18n("You cannot use protected name."), i18n("New Script"));
+        return;
+    }
+
     u.setFileName( name );
 
     mCurrentCapabilities = currentItem->data(0, SIEVE_SERVER_CAPABILITIES).toStringList();
@@ -537,7 +517,7 @@ void ManageSieveScriptsDialog::slotSieveEditorOkClicked()
     if ( !mSieveEditor )
         return;
     disableManagerScriptsDialog(false);
-    KManageSieve::SieveJob * job = KManageSieve::SieveJob::put( mCurrentURL,mSieveEditor->script(), mWasActive, mWasActive );
+    KManageSieve::SieveJob * job = KManageSieve::SieveJob::put(mCurrentURL,mSieveEditor->script(), mWasActive, mWasActive );
     connect( job, SIGNAL(result(KManageSieve::SieveJob*,bool,QString,bool)),
              this, SLOT(slotPutResult(KManageSieve::SieveJob*,bool)) );
 }
@@ -595,8 +575,10 @@ void ManageSieveScriptsDialog::addOkMessage( const QString &err )
 
 void ManageSieveScriptsDialog::addMessageEntry( const QString &errorMsg, const QColor &color )
 {
-    mSieveEditor->setDebugColor( color );
-    mSieveEditor->setDebugScript( errorMsg );
+    const QString logText = QString::fromLatin1( "<font color=%1>%2</font>" )
+            .arg( color.name() ).arg(errorMsg);
+
+    mSieveEditor->setDebugScript( logText );
 }
 
 void ManageSieveScriptsDialog::disableManagerScriptsDialog(bool disable)
@@ -604,5 +586,4 @@ void ManageSieveScriptsDialog::disableManagerScriptsDialog(bool disable)
     setDisabled(disable);
 }
 
-
 #include "managesievescriptsdialog.moc"
