@@ -14,15 +14,14 @@
 
 #include "vacation.h"
 
-#include "settings.h"
-#include "util.h"
+#include "sieve-vacation.h"
+#include "util/util.h"
 #include "vacationdialog.h"
 #include <kmanagesieve/sievejob.h>
 
 #include <akonadi/agentinstance.h>
 #include <kdebug.h>
 #include <kglobal.h>
-#include <kimap/loginjob.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kmime/kmime_header_parsing.h>
@@ -32,8 +31,6 @@
 #include <ksieve/parser.h>
 #include <ksieve/scriptbuilder.h>
 
-#include <QtCore/QByteArray>
-
 #include <cassert>
 #include <limits.h>
 #include <map>
@@ -418,12 +415,18 @@ private:
 
 using namespace KSieveUi;
 
-Vacation::Vacation( QObject * parent, bool checkOnly, const char * name )
-    : QObject( parent ), mSieveJob( 0 ), mDialog( 0 ), mWasActive( false ),
+Vacation::Vacation(QObject * parent, bool checkOnly, const KUrl &url)
+    : QObject( parent ),
+      mSieveJob( 0 ),
+      mDialog( 0 ),
+      mWasActive( false ),
       mCheckOnly( checkOnly )
 {
-    setObjectName( QString::fromLatin1(name) );
-    mUrl = findURL();
+    if (url.isEmpty()) {
+        mUrl = findURL(mServerName);
+    } else {
+        mUrl = url;
+    }
     kDebug() << "Vacation: found url \"" << mUrl.prettyUrl() <<"\"";
     if ( mUrl.isEmpty() ) // nothing to do...
         return;
@@ -436,8 +439,11 @@ Vacation::Vacation( QObject * parent, bool checkOnly, const char * name )
 }
 
 Vacation::~Vacation() {
-    if ( mSieveJob ) mSieveJob->kill(); mSieveJob = 0;
-    delete mDialog; mDialog = 0;
+    if ( mSieveJob )
+        mSieveJob->kill();
+    mSieveJob = 0;
+    delete mDialog;
+    mDialog = 0;
     kDebug() << "~Vacation()";
 }
 
@@ -484,7 +490,7 @@ QString Vacation::composeScript( const QString & messageText,
 }
 
 
-KUrl Vacation::findURL() const
+KUrl Vacation::findURL(QString &serverName) const
 {
     const Akonadi::AgentInstance::List instances = Util::imapAgentInstances();
     foreach ( const Akonadi::AgentInstance &instance, instances ) {
@@ -492,8 +498,10 @@ KUrl Vacation::findURL() const
             continue;
 
         const KUrl url = Util::findSieveUrlForAccount( instance.identifier() );
-        if ( !url.isEmpty() )
+        if ( !url.isEmpty() ) {
+            serverName = instance.name();
             return url;
+        }
     }
 
     return KUrl();
@@ -528,7 +536,7 @@ bool Vacation::parseScript( const QString & script, QString & messageText,
     messageText = vdx.messageText().trimmed();
     notificationInterval = vdx.notificationInterval();
     aliases = vdx.aliases();
-    if ( !Settings::allowOutOfOfficeUploadButNoSettings() ) {
+    if ( !VacationSettings::allowOutOfOfficeUploadButNoSettings() ) {
         sendForSpam = !sdx.found();
         domainName = drdx.domainName();
     }
@@ -538,14 +546,14 @@ bool Vacation::parseScript( const QString & script, QString & messageText,
 QString Vacation::defaultMessageText() {
     return i18n( "I am out of office till %1.\n"
                  "\n"
-                 "In urgent cases, please contact Mrs. <placeholder>vacation replacement</placeholder>\n"
+                 "In urgent cases, please contact Mrs. \"vacation replacement\"\n"
                  "\n"
-                 "email: <placeholder>email address of vacation replacement</placeholder>\n"
+                 "email: \"email address of vacation replacement\"\n"
                  "phone: +49 711 1111 11\n"
                  "fax.:  +49 711 1111 12\n"
                  "\n"
                  "Yours sincerely,\n"
-                 "-- <placeholder>enter your name and email address here</placeholder>\n",
+                 "-- \"enter your name and email address here\"\n",
                  KGlobal::locale()->formatDate( QDate::currentDate().addDays( 1 ) ) );
 }
 
@@ -568,11 +576,11 @@ QStringList Vacation::defaultMailAliases()
 }
 
 bool Vacation::defaultSendForSpam() {
-    return Settings::outOfOfficeReactToSpam();
+    return VacationSettings::outOfOfficeReactToSpam();
 }
 
 QString Vacation::defaultDomainName() {
-    return Settings::outOfOfficeDomain();
+    return VacationSettings::outOfOfficeDomain();
 }
 
 void Vacation::slotGetResult( KManageSieve::SieveJob * job, bool success,
@@ -619,7 +627,7 @@ void Vacation::slotGetResult( KManageSieve::SieveJob * job, bool success,
         mDialog->setMailAliases( aliases.join(QLatin1String(", ")) );
         mDialog->setSendForSpam( sendForSpam );
         mDialog->setDomainName( domainName );
-        mDialog->enableDomainAndSendForSpam( !Settings::allowOutOfOfficeUploadButNoSettings() );
+        mDialog->enableDomainAndSendForSpam( !VacationSettings::allowOutOfOfficeUploadButNoSettings() );
 
         connect( mDialog, SIGNAL(okClicked()), SLOT(slotDialogOk()) );
         connect( mDialog, SIGNAL(cancelClicked()), SLOT(slotDialogCancel()) );
@@ -628,7 +636,7 @@ void Vacation::slotGetResult( KManageSieve::SieveJob * job, bool success,
         mDialog->show();
     }
 
-    emit scriptActive( mWasActive );
+    emit scriptActive( mWasActive, mServerName );
     if ( mCheckOnly && mWasActive ) {
         if ( KMessageBox::questionYesNo( 0, i18n( "There is still an active out-of-office reply configured.\n"
                                                   "Do you want to edit it?"), i18n("Out-of-office reply still active"),
@@ -661,7 +669,7 @@ void Vacation::slotDialogOk() {
                                           mDialog->sendForSpam(),
                                           mDialog->domainName() );
     const bool active = mDialog->activateVacation();
-    emit scriptActive( active );
+    emit scriptActive( active, mServerName);
 
     kDebug() << "script:" << endl << script;
 
@@ -705,7 +713,7 @@ void Vacation::handlePutResult( KManageSieve::SieveJob *, bool success, bool act
     kDebug() << "( ???," << success << ", ? )";
     mSieveJob = 0; // job deletes itself after returning from this slot!
     emit result( success );
-    emit scriptActive( activated );
+    emit scriptActive( activated, mServerName );
 }
 
 void Vacation::showVacationDialog()
