@@ -238,6 +238,300 @@ void SearchRule::writeConfig( KConfigGroup &config, int aIdx ) const
   config.writeEntry( contents + cIdx, mContents );
 }
 
+QString SearchRule::conditionToString(Function function)
+{
+    QString str;
+    switch(function) {
+    case FuncEquals:
+        str = i18n("equal");
+        break;
+    case FuncNotEqual:
+        str = i18n("not equal");
+        break;
+    case FuncIsGreater:
+        str = i18n("is greater");
+        break;
+    case FuncIsLessOrEqual:
+        str = i18n("is less or equal");
+        break;
+    case FuncIsLess:
+        str = i18n("is less");
+        break;
+    case FuncIsGreaterOrEqual:
+        str = i18n("is greater or equal");
+        break;
+    case FuncIsInAddressbook:
+        str = i18n("is in addressbook");
+        break;
+    case FuncIsNotInAddressbook:
+        str = i18n("is not in addressbook");
+        break;
+    case FuncIsInCategory:
+        str = i18n("is in category");
+        break;
+    case FuncIsNotInCategory:
+        str = i18n("is in category");
+        break;
+    case FuncHasAttachment:
+        str = i18n("has an attachment");
+        break;
+    case FuncHasNoAttachment:
+        str = i18n("has not an attachment");
+        break;
+    case FuncStartWith:
+        str = i18n("start with");
+        break;
+    case FuncNotStartWith:
+        str = i18n("not start with");
+        break;
+    case FuncEndWith:
+        str = i18n("end with");
+        break;
+    case FuncNotEndWith:
+        str = i18n("not end with");
+        break;
+    case FuncNone:
+        str = i18n("none");
+        break;
+    case FuncContains:
+        str = i18n("contains");
+        break;
+    case FuncContainsNot:
+        str = i18n("not contains");
+        break;
+    case FuncRegExp:
+        str = i18n("has regexp");
+        break;
+    case FuncNotRegExp:
+        str = i18n("not regexp");
+        break;
+    }
+    return str;
+}
+
+void SearchRule::generateSieveScript(QStringList &requires, QString &code)
+{
+    QString contentStr = mContents;
+    if (mField == "<size>") {
+        QString comparaison;
+        int offset = 0;
+        switch(mFunction) {
+        case FuncEquals:
+            comparaison = QLatin1Char('"') + i18n("size equals not supported") + QLatin1Char('"');
+            break;
+        case FuncNotEqual:
+            comparaison = QLatin1Char('"') + i18n("size not equals not supported") + QLatin1Char('"');
+            break;
+        case FuncIsGreater:
+            comparaison = QLatin1String(":over");
+            break;
+        case FuncIsLessOrEqual:
+            comparaison = QLatin1String(":under");
+            offset = 1;
+            break;
+        case FuncIsLess:
+            comparaison = QLatin1String(":under");
+            break;
+        case FuncIsGreaterOrEqual:
+            comparaison = QLatin1String(":over");
+            offset = -1;
+            break;
+        case FuncIsInAddressbook:
+        case FuncIsNotInAddressbook:
+        case FuncIsInCategory:
+        case FuncIsNotInCategory:
+        case FuncHasAttachment:
+        case FuncHasNoAttachment:
+        case FuncStartWith:
+        case FuncNotStartWith:
+        case FuncEndWith:
+        case FuncNotEndWith:
+        case FuncNone:
+        case FuncContains:
+        case FuncContainsNot:
+        case FuncRegExp:
+        case FuncNotRegExp:
+            code += QLatin1Char('"') + i18n("\"%1\" is not supported with condition \"%2\"", QLatin1String(mField), conditionToString(mFunction)) + QLatin1Char('"');
+            return;
+        }
+        code += QString::fromLatin1("size %1 %2K").arg(comparaison).arg(QString::number(mContents.toInt() + offset));
+    } else if (mField == "<status>") {
+        //TODO ?
+        code += QLatin1Char('"') + i18n("<status> not implemented/supported") + QLatin1Char('"');
+    } else if (mField == "<any header>") {
+        //TODO ?
+        code += QLatin1Char('"') + i18n("<any header> not implemented/supported") + QLatin1Char('"');
+    } else if (mField == "contents") {
+        //TODO ?
+        code += QLatin1Char('"') + i18n("<contents> not implemented/supported") + QLatin1Char('"');
+    } else if (mField == "<age in days>") {
+        //TODO ?
+        code += QLatin1Char('"') + i18n("<age in days> not implemented/supported") + QLatin1Char('"');
+    } else if (mField == "<date>") {
+        //TODO ?
+        code += QLatin1Char('"') + i18n("<date> not implemented/supported") + QLatin1Char('"');
+    } else if (mField == "<recipients>") {
+        //TODO ?
+        code += QLatin1Char('"') + i18n("<recipients> not implemented/supported") + QLatin1Char('"');
+    } else if (mField == "<tag>") {
+        code += QLatin1Char('"') + i18n("<Tag> is not supported") + QLatin1Char('"');
+    } else if (mField == "<message>") {
+        //TODO ?
+        code += i18n("<message> not implemented/supported");
+    } else if (mField == "<body>") {
+        if (!requires.contains(QLatin1String("body")))
+            requires << QLatin1String("body");
+        QString comparaison;
+        bool negative = false;
+        switch(mFunction) {
+        case FuncNone:
+            break;
+        case FuncContains:
+            comparaison = QLatin1String(":contains");
+            break;
+        case FuncContainsNot:
+            negative = true;
+            comparaison = QLatin1String(":contains");
+            break;
+        case FuncEquals:
+            comparaison = QLatin1String(":is");
+            break;
+        case FuncNotEqual:
+            comparaison = QLatin1String(":is");
+            negative = true;
+            break;
+        case FuncRegExp:
+            comparaison = QLatin1String(":regex");
+            if (!requires.contains(QLatin1String("regex")))
+                requires << QLatin1String("regex");
+            break;
+        case FuncNotRegExp:
+            if (!requires.contains(QLatin1String("regex")))
+                requires << QLatin1String("regex");
+            comparaison = QLatin1String(":regex");
+            negative = true;
+            break;
+        case FuncStartWith:
+            comparaison = QLatin1String(":regex");
+            if (!requires.contains(QLatin1String("regex")))
+                requires << QLatin1String("regex");
+            contentStr = QLatin1Char('^') + contentStr;
+            break;
+        case FuncNotStartWith:
+            comparaison = QLatin1String(":regex");
+            if (!requires.contains(QLatin1String("regex")))
+                requires << QLatin1String("regex");
+            comparaison = QLatin1String(":regex");
+            contentStr = QLatin1Char('^') + contentStr;
+            negative = true;
+            break;
+        case FuncEndWith:
+            comparaison = QLatin1String(":regex");
+            if (!requires.contains(QLatin1String("regex")))
+                requires << QLatin1String("regex");
+            comparaison = QLatin1String(":regex");
+            contentStr = contentStr + QLatin1Char('$');
+            break;
+        case FuncNotEndWith:
+            comparaison = QLatin1String(":regex");
+            if (!requires.contains(QLatin1String("regex")))
+                requires << QLatin1String("regex");
+            comparaison = QLatin1String(":regex");
+            contentStr = contentStr + QLatin1Char('$');
+            negative = true;
+            break;
+        case FuncIsGreater:
+        case FuncIsLessOrEqual:
+        case FuncIsLess:
+        case FuncIsGreaterOrEqual:
+        case FuncIsInAddressbook:
+        case FuncIsNotInAddressbook:
+        case FuncIsInCategory:
+        case FuncIsNotInCategory:
+        case FuncHasAttachment:
+        case FuncHasNoAttachment:
+            code += QLatin1Char('"') + i18n("\"%1\" is not supported with condition \"%2\"", QLatin1String(mField), conditionToString(mFunction)) + QLatin1Char('"');
+            return;
+        }
+        code += (negative ? QLatin1String("not ") : QString()) + QString::fromLatin1("body :text %1 \"%2\"").arg(comparaison).arg(contentStr);
+    } else {
+        QString comparaison;
+        bool negative = false;
+        switch(mFunction) {
+        case FuncNone:
+            break;
+        case FuncContains:
+            comparaison = QLatin1String(":contains");
+            break;
+        case FuncContainsNot:
+            negative = true;
+            comparaison = QLatin1String(":contains");
+            break;
+        case FuncEquals:
+            comparaison = QLatin1String(":is");
+            break;
+        case FuncNotEqual:
+            comparaison = QLatin1String(":is");
+            negative = true;
+            break;
+        case FuncRegExp:
+            comparaison = QLatin1String(":regex");
+            if (!requires.contains(QLatin1String("regex")))
+                requires << QLatin1String("regex");
+            break;
+        case FuncNotRegExp:
+            if (!requires.contains(QLatin1String("regex")))
+                requires << QLatin1String("regex");
+            comparaison = QLatin1String(":regex");
+            negative = true;
+            break;
+        case FuncStartWith:
+            comparaison = QLatin1String(":regex");
+            if (!requires.contains(QLatin1String("regex")))
+                requires << QLatin1String("regex");
+            contentStr = QLatin1Char('^') + contentStr;
+            break;
+        case FuncNotStartWith:
+            comparaison = QLatin1String(":regex");
+            if (!requires.contains(QLatin1String("regex")))
+                requires << QLatin1String("regex");
+            comparaison = QLatin1String(":regex");
+            contentStr = QLatin1Char('^') + contentStr;
+            negative = true;
+            break;
+        case FuncEndWith:
+            comparaison = QLatin1String(":regex");
+            if (!requires.contains(QLatin1String("regex")))
+                requires << QLatin1String("regex");
+            comparaison = QLatin1String(":regex");
+            contentStr = contentStr + QLatin1Char('$');
+            break;
+        case FuncNotEndWith:
+            comparaison = QLatin1String(":regex");
+            if (!requires.contains(QLatin1String("regex")))
+                requires << QLatin1String("regex");
+            comparaison = QLatin1String(":regex");
+            contentStr = contentStr + QLatin1Char('$');
+            negative = true;
+            break;
+
+        case FuncIsGreater:
+        case FuncIsLessOrEqual:
+        case FuncIsLess:
+        case FuncIsGreaterOrEqual:
+        case FuncIsInAddressbook:
+        case FuncIsNotInAddressbook:
+        case FuncIsInCategory:
+        case FuncIsNotInCategory:
+        case FuncHasAttachment:
+        case FuncHasNoAttachment:
+            code += QLatin1Char('"') + i18n("\"%1\" is not supported with condition \"%2\"", QLatin1String(mField), conditionToString(mFunction)) + QLatin1Char('"');
+            return;
+        }
+        code += (negative ? QLatin1String("not ") : QString()) + QString::fromLatin1("header %1 \"%2\" \"%3\"").arg(comparaison).arg(QLatin1String(mField)).arg(contentStr);
+    }
+}
+
 void SearchRule::setFunction( Function function )
 {
   mFunction = function;
@@ -348,44 +642,6 @@ void SearchRule::addAndNegateTerm( const Nepomuk2::Query::Term &term,
   }
 }
 
-
-QString SearchRule::xesamComparator() const
-{
-  switch ( function() ) {
-  case SearchRule::FuncContains:
-  case SearchRule::FuncContainsNot:
-    return QLatin1String( "contains" );
-
-  case SearchRule::FuncEquals:
-  case SearchRule::FuncNotEqual:
-    return QLatin1String( "equals" );
-
-  case SearchRule::FuncIsGreater:
-    return QLatin1String( "greaterThan" );
-
-  case SearchRule::FuncIsGreaterOrEqual:
-    return QLatin1String( "greaterThanEquals" );
-
-  case SearchRule::FuncIsLess:
-    return QLatin1String( "lessThan" );
-
-  case SearchRule::FuncIsLessOrEqual:
-    return QLatin1String( "lessThanEquals" );
-
-  // FIXME how to handle the below? full text?
-  case SearchRule::FuncRegExp:
-  case SearchRule::FuncNotRegExp:
-  case SearchRule::FuncStartWith:
-  case SearchRule::FuncNotStartWith:
-  case SearchRule::FuncEndWith:
-  case SearchRule::FuncNotEndWith:
-  default:
-    kDebug() << "Unhandled function type: " << function();
-  }
-
-  return QLatin1String( "equals" );
-}
-
 QDataStream &SearchRule::operator >>( QDataStream &s ) const
 {
   s << mField << functionToString( mFunction ) << mContents;
@@ -609,8 +865,9 @@ void SearchRuleString::addHeaderTerm( Nepomuk2::Query::GroupTerm &groupTerm,
 
 }
 
-void SearchRuleString::addQueryTerms( Nepomuk2::Query::GroupTerm &groupTerm ) const
+void SearchRuleString::addQueryTerms(Nepomuk2::Query::GroupTerm &groupTerm , bool &emptyIsNotAnError) const
 {
+  emptyIsNotAnError = false;
   Nepomuk2::Query::OrTerm termGroup;
   if ( kasciistricmp( field(), "<message>" ) == 0 ||
        kasciistricmp( field(), "<recipients>" ) == 0  ||
@@ -887,29 +1144,6 @@ bool SearchRuleString::matchesInternal( const QString &msgContents ) const
   return false;
 }
 
-void SearchRuleString::addXesamClause( QXmlStreamWriter &stream ) const
-{
-  const QString func = xesamComparator();
-
-  stream.writeStartElement( func );
-
-  if ( field().toLower() == "subject"  ||
-       field().toLower() == "to"  ||
-       field().toLower() == "cc"  ||
-       field().toLower() == "bcc"  ||
-       field().toLower() == "from"  ||
-       field().toLower() == "sender" ) {
-    stream.writeStartElement( QLatin1String( "field" ) );
-    stream.writeAttribute( QLatin1String( "name" ), field().toLower() );
-  } else {
-    stream.writeStartElement( QLatin1String( "fullTextFields" ) );
-  }
-  stream.writeEndElement();
-  stream.writeTextElement( QLatin1String( "string" ), contents() );
-
-  stream.writeEndElement();
-}
-
 //==================================================
 //
 // class SearchRuleNumerical
@@ -1020,8 +1254,9 @@ bool SearchRuleNumerical::matchesInternal( long numericalValue,
 }
 
 
-void SearchRuleNumerical::addQueryTerms( Nepomuk2::Query::GroupTerm &groupTerm ) const
+void SearchRuleNumerical::addQueryTerms(Nepomuk2::Query::GroupTerm &groupTerm , bool &emptyIsNotAnError) const
 {
+  emptyIsNotAnError = false;
   if ( kasciistricmp( field(), "<size>" ) == 0 ) {
     const Nepomuk2::Query::ComparisonTerm sizeTerm(
       Vocabulary::NIE::byteSize(),
@@ -1039,12 +1274,6 @@ void SearchRuleNumerical::addQueryTerms( Nepomuk2::Query::GroupTerm &groupTerm )
   }
 }
 
-void SearchRuleNumerical::addXesamClause( QXmlStreamWriter &stream ) const
-{
-  Q_UNUSED( stream );
-}
-
-
 //==================================================
 //
 // class SearchRuleDate
@@ -1116,8 +1345,9 @@ SearchRule::RequiredPart SearchRuleDate::requiredPart() const
 
 
 
-void SearchRuleDate::addQueryTerms( Nepomuk2::Query::GroupTerm &groupTerm ) const
+void SearchRuleDate::addQueryTerms(Nepomuk2::Query::GroupTerm &groupTerm , bool &emptyIsNotAnError) const
 {
+    emptyIsNotAnError = false;
     const QDate date = QDate::fromString( contents(), Qt::ISODate );
     const Nepomuk2::Query::ComparisonTerm dateTerm(
       Vocabulary::NMO::sentDate(),
@@ -1126,11 +1356,6 @@ void SearchRuleDate::addQueryTerms( Nepomuk2::Query::GroupTerm &groupTerm ) cons
     addAndNegateTerm( dateTerm, groupTerm );
 }
 
-void SearchRuleDate::addXesamClause( QXmlStreamWriter &stream ) const
-{
-  Q_UNUSED( stream );
-}
-
 
 //==================================================
 //
@@ -1214,13 +1439,14 @@ SearchRule::RequiredPart SearchRuleStatus::requiredPart() const
   return SearchRule::Envelope;
 }
 
-
 void SearchRuleStatus::addTagTerm( Nepomuk2::Query::GroupTerm &groupTerm,
                                    const QString &tagId ) const
 {
   // TODO handle function() == NOT
+    qDebug()<<" tagId"<<tagId;
   const Nepomuk2::Tag tag( tagId );
   if (tag.exists()) {
+      qDebug()<<" tag exist !";
     addAndNegateTerm(
       Nepomuk2::Query::ComparisonTerm(
         Soprano::Vocabulary::NAO::hasTag(),
@@ -1230,8 +1456,9 @@ void SearchRuleStatus::addTagTerm( Nepomuk2::Query::GroupTerm &groupTerm,
   }
 }
 
-void SearchRuleStatus::addQueryTerms( Nepomuk2::Query::GroupTerm &groupTerm ) const
+void SearchRuleStatus::addQueryTerms(Nepomuk2::Query::GroupTerm &groupTerm , bool &emptyIsNotAnError) const
 {
+  emptyIsNotAnError = true;
   if ( mStatus.isImportant() ) {
     addTagTerm( groupTerm, "important" );
   } else if ( mStatus.isToAct() ) {
@@ -1270,13 +1497,6 @@ void SearchRuleStatus::addQueryTerms( Nepomuk2::Query::GroupTerm &groupTerm ) co
           Nepomuk2::Query::ComparisonTerm::Equal ) );
 
   }
-
-  // TODO
-}
-
-void SearchRuleStatus::addXesamClause( QXmlStreamWriter &stream ) const
-{
-  Q_UNUSED( stream );
 }
 
 // ----------------------------------------------------------------------------
@@ -1470,7 +1690,7 @@ void SearchPattern::writeConfig( KConfigGroup &config ) const
   QList<SearchRule::Ptr>::const_iterator it;
   QList<SearchRule::Ptr>::const_iterator endIt( constEnd() );
 
-  for ( it = begin(); it != endIt && i < FILTER_MAX_RULES; ++i, ++it ) {
+  for ( it = constBegin(); it != endIt && i < FILTER_MAX_RULES; ++i, ++it ) {
     // we could do this ourselves, but we want the rules to be extensible,
     // so we give the rule it's number and let it do the rest.
     (*it)->writeConfig( config, i );
@@ -1503,8 +1723,8 @@ QString SearchPattern::asString() const
   }
 
   QList<SearchRule::Ptr>::const_iterator it;
-  QList<SearchRule::Ptr>::const_iterator endIt = end();
-  for ( it = begin(); it != endIt; ++it ) {
+  QList<SearchRule::Ptr>::const_iterator endIt = constEnd();
+  for ( it = constBegin(); it != endIt; ++it ) {
     result += "\n\t" + FilterLog::recode( (*it)->asString() );
   }
 
@@ -1532,9 +1752,8 @@ Nepomuk2::Query::ComparisonTerm SearchPattern::createChildTerm( const KUrl& url,
   return isChildTerm;
 }
 
-QString SearchPattern::asSparqlQuery(bool &allIsEmpty, const KUrl::List& urlList) const
+MailCommon::SearchPattern::SparqlQueryError SearchPattern::asSparqlQuery(QString &queryStr, const KUrl::List& urlList) const
 {
-
   Nepomuk2::Query::Query query;
 
   Nepomuk2::Query::AndTerm outerGroup;
@@ -1545,14 +1764,20 @@ QString SearchPattern::asSparqlQuery(bool &allIsEmpty, const KUrl::List& urlList
 
   Nepomuk2::Query::GroupTerm innerGroup = makeGroupTerm( mOperator );
   const_iterator end( constEnd() );
+  bool emptyIsNotAnError = false;
+  bool resultAddQuery = emptyIsNotAnError;
   for ( const_iterator it = constBegin(); it != end; ++it ) {
-    (*it)->addQueryTerms( innerGroup );
+    (*it)->addQueryTerms( innerGroup, emptyIsNotAnError );
+    resultAddQuery &= emptyIsNotAnError;
   }
 
-
   if ( innerGroup.subTerms().isEmpty() ) {
-    qDebug()<<" innergroup is Empty. Need to report bug";
-    return QString();
+      if (resultAddQuery) {
+          qDebug()<<" innergroup is Empty. Need to report bug";
+          return MissingCheck;
+      } else {
+          return EmptyResult;
+      }
   }
   if ( !urlList.isEmpty() ) {
     const int numberOfUrl = urlList.count();
@@ -1560,8 +1785,7 @@ QString SearchPattern::asSparqlQuery(bool &allIsEmpty, const KUrl::List& urlList
       bool empty = false;
       const Nepomuk2::Query::ComparisonTerm isChildTerm = createChildTerm( urlList.at( 0 ), empty );
       if ( empty ) {
-        allIsEmpty = true;
-        return QString();
+        return FolderEmptyOrNotIndexed;
       }
       const Nepomuk2::Query::AndTerm andTerm( isChildTerm, innerGroup );
       outerGroup.addSubTerm( andTerm );
@@ -1577,8 +1801,7 @@ QString SearchPattern::asSparqlQuery(bool &allIsEmpty, const KUrl::List& urlList
         }
       }
       if (allFolderIsEmpty) {
-        allIsEmpty = true;
-        return QString();
+        return FolderEmptyOrNotIndexed;
       }
       const Nepomuk2::Query::OrTerm orTerm( term );
       const Nepomuk2::Query::AndTerm andTerm( orTerm, innerGroup );
@@ -1591,46 +1814,10 @@ QString SearchPattern::asSparqlQuery(bool &allIsEmpty, const KUrl::List& urlList
   outerGroup.addSubTerm( typeTerm );
   query.setTerm( outerGroup );
   query.addRequestProperty( itemIdProperty );
-  allIsEmpty = false;
-  return query.toSparqlQuery();
+  queryStr = query.toSparqlQuery();
+  return NoError;
 }
 
-QString MailCommon::SearchPattern::asXesamQuery() const
-{
-  QString query;
-  QXmlStreamWriter stream( &query );
-  stream.setAutoFormatting( true );
-  stream.writeStartDocument();
-  stream.writeStartElement( QLatin1String( "request" ) );
-  stream.writeAttribute( QLatin1String( "xmlns" ),
-                         QLatin1String( "http://freedesktop.org/standards/xesam/1.0/query" ) );
-  stream.writeStartElement( QLatin1String( "query" ) );
-
-  const bool needsOperator = count() > 1;
-  if ( needsOperator ) {
-    if ( mOperator == SearchPattern::OpOr ) {
-      stream.writeStartElement( QLatin1String( "or" ) );
-    } else if ( mOperator == SearchPattern::OpAnd ) {
-      stream.writeStartElement( QLatin1String( "and" ) );
-    } else {
-      Q_ASSERT( false ); // can't happen (TM)
-    }
-  }
-
-  QListIterator<SearchRule::Ptr> it( *this );
-  while ( it.hasNext() ) {
-    const SearchRule::Ptr rule = it.next();
-    rule->addXesamClause( stream );
-  }
-
-  if ( needsOperator ) {
-    stream.writeEndElement(); // operator
-  }
-  stream.writeEndElement(); // query
-  stream.writeEndElement(); // request
-  stream.writeEndDocument();
-  return query;
-}
 
 const SearchPattern & SearchPattern::operator=( const SearchPattern &other )
 {
@@ -1704,6 +1891,32 @@ QDataStream &SearchPattern::operator<<( QDataStream &s )
   return s;
 }
 
+void SearchPattern::generateSieveScript(QStringList &requires, QString &code)
+{
+    code += QLatin1String("\n#") + mName + QLatin1Char('\n');
+    switch( mOperator ) {
+    case OpOr:
+        code += QLatin1String("if anyof (");
+      break;
+    case OpAnd:
+        code += QLatin1String("if allof (");
+      break;
+    case OpAll:
+        code += QLatin1String("if (true) {");
+        return;
+    }
+
+    QList<SearchRule::Ptr>::const_iterator it;
+    QList<SearchRule::Ptr>::const_iterator endIt( constEnd() );
+    int i = 0;
+    for ( it = constBegin(); it != endIt && i < FILTER_MAX_RULES; ++i, ++it ) {
+        if (i != 0) {
+            code += QLatin1String("\n, ");
+        }
+        (*it)->generateSieveScript(requires, code);
+    }
+}
+
 // Needed for MSVC 2010, as it seems to not implicit cast for a pointer anymore
 #ifdef _MSC_VER
 namespace MailCommon {
