@@ -85,16 +85,16 @@ static const int SpecialRuleFieldsCount =
 //
 //=============================================================================
 
-SearchRuleWidget::SearchRuleWidget( QWidget *parent, SearchRule::Ptr aRule,
-                                    bool headersOnly, bool absoluteDates )
-  : QWidget( parent ),
+SearchRuleWidget::SearchRuleWidget(QWidget *parent, SearchRule::Ptr aRule,
+                                   SearchPatternEdit::SearchPatternEditOptions options ,
+                                   SearchPatternEdit::SearchModeType modeType)
+    : QWidget( parent ),
     mRuleField( 0 ),
     mFunctionStack( 0 ),
-    mValueStack( 0 ),
-    mAbsoluteDates( absoluteDates )
+    mValueStack( 0 )
 {
-  initFieldList( headersOnly, absoluteDates );
-  initWidget();
+  initFieldList( options );
+  initWidget( modeType );
 
   if ( aRule ) {
     setRule( aRule );
@@ -103,12 +103,12 @@ SearchRuleWidget::SearchRuleWidget( QWidget *parent, SearchRule::Ptr aRule,
   }
 }
 
-void SearchRuleWidget::setHeadersOnly( bool headersOnly )
+void SearchRuleWidget::setPatternEditOptions( SearchPatternEdit::SearchPatternEditOptions options )
 {
   SearchRule::Ptr srule = rule();
   QByteArray currentText = srule->field();
 
-  initFieldList( headersOnly, mAbsoluteDates );
+  initFieldList( options );
 
   mRuleField->clear();
   mRuleField->addItems( mFilterFieldList );
@@ -118,14 +118,39 @@ void SearchRuleWidget::setHeadersOnly( bool headersOnly )
   mRuleField->setMaxCount( mRuleField->count() );
   mRuleField->adjustSize();
 
-  if ( ( currentText != "<message>") && ( currentText != "<body>" ) ) {
+  const bool headersOnly = ( options & MailCommon::SearchPatternEdit::HeadersOnly );
+  const bool notShowSize = ( options & MailCommon::SearchPatternEdit::NotShowSize );
+  const bool notShowDate = ( options & MailCommon::SearchPatternEdit::NotShowDate );
+  const bool absoluteDates = ( options & MailCommon::SearchPatternEdit::AbsoluteDate );
+
+  if ( headersOnly && ( currentText != "<message>") && ( currentText != "<body>" ) ) {
+    mRuleField->setItemText( 0, QString::fromLatin1( currentText ) );
+  } else {
+    mRuleField->setItemText( 0, QString() );
+  }
+
+  if ( notShowSize && ( currentText != "<size>") ) {
+    mRuleField->setItemText( 0, QString::fromLatin1( currentText ) );
+  } else {
+    mRuleField->setItemText( 0, QString() );
+  }
+
+  if ( notShowDate && ( currentText != "<date>") ) {
+    mRuleField->setItemText( 0, QString::fromLatin1( currentText ) );
+  } else {
+    mRuleField->setItemText( 0, QString() );
+  }
+
+  if ( !absoluteDates && ( currentText != "<age in days>") ) {
     mRuleField->setItemText( 0, QString::fromLatin1( currentText ) );
   } else {
     mRuleField->setItemText( 0, QString() );
   }
 }
 
-void SearchRuleWidget::initWidget()
+
+
+void SearchRuleWidget::initWidget(SearchPatternEdit::SearchModeType modeType)
 {
   QHBoxLayout *hlay = new QHBoxLayout( this );
   hlay->setSpacing( KDialog::spacingHint() );
@@ -133,7 +158,7 @@ void SearchRuleWidget::initWidget()
 
   // initialize the header field combo box
   mRuleField = new PimCommon::MinimumComboBox( this );
-  mRuleField->setObjectName( "mRuleField" );
+  mRuleField->setObjectName( QLatin1String("mRuleField") );
   mRuleField->setEditable( true );
   KLineEdit *edit = new KLineEdit;
   edit->setClickMessage( i18n("Choose or type your own criteria"));
@@ -165,15 +190,17 @@ void SearchRuleWidget::initWidget()
   hlay->setStretchFactor( mValueStack, 10 );
 
   mAdd = new KPushButton( this );
-  mAdd->setIcon( KIcon( "list-add" ) );
+  mAdd->setIcon( KIcon( QLatin1String("list-add") ) );
   mAdd->setSizePolicy( QSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed ) );
   hlay->addWidget( mAdd );
 
   mRemove = new KPushButton( this );
-  mRemove->setIcon( KIcon( "list-remove" ) );
+  mRemove->setIcon( KIcon( QLatin1String("list-remove") ) );
   mRemove->setSizePolicy( QSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed ) );
   hlay->addWidget( mRemove );
 
+  RuleWidgetHandlerManager::instance()->setIsNepomukSearch(modeType==SearchPatternEdit::NepomukMode);
+
   RuleWidgetHandlerManager::instance()->createWidgets( mFunctionStack, mValueStack, this );
 
   // redirect focus to the header field combo box
@@ -248,7 +275,7 @@ SearchRule::Ptr SearchRuleWidget::rule() const
 void SearchRuleWidget::reset()
 {
   mRuleField->blockSignals( true );
-  mRuleField->setItemText( 0, "" );
+  mRuleField->setItemText( 0, QString() );
   mRuleField->setCurrentIndex( 0 );
   mRuleField->blockSignals( false );
 
@@ -303,11 +330,11 @@ int SearchRuleWidget::ruleFieldToId( const QString & i18nVal )
 static QString displayNameFromInternalName( const QString & internal )
 {
   for ( int i = 0; i < SpecialRuleFieldsCount; ++i ) {
-    if ( internal == SpecialRuleFields[i].internalName ) {
+    if ( internal == QLatin1String(SpecialRuleFields[i].internalName) ) {
       return SpecialRuleFields[i].getLocalizedDisplayName();
     }
   }
-  return internal.toLatin1();
+  return QLatin1String(internal.toLatin1());
 }
 
 int SearchRuleWidget::indexOfRuleField( const QByteArray &aName ) const
@@ -316,7 +343,7 @@ int SearchRuleWidget::indexOfRuleField( const QByteArray &aName ) const
     return -1;
   }
 
-  const QString i18n_aName = displayNameFromInternalName( aName );
+  const QString i18n_aName = displayNameFromInternalName( QLatin1String(aName) );
   const int nbRuleField = mRuleField->count();
   for ( int i = 1; i < nbRuleField; ++i ) {
     if ( mRuleField->itemText( i ) == i18n_aName ) {
@@ -327,10 +354,15 @@ int SearchRuleWidget::indexOfRuleField( const QByteArray &aName ) const
   return -1;
 }
 
-void SearchRuleWidget::initFieldList( bool headersOnly, bool absoluteDates )
+void SearchRuleWidget::initFieldList( SearchPatternEdit::SearchPatternEditOptions options )
 {
+  const bool headersOnly = ( options & MailCommon::SearchPatternEdit::HeadersOnly );
+  const bool absoluteDates = ( options & MailCommon::SearchPatternEdit::AbsoluteDate );
+  const bool notShowSize = ( options & MailCommon::SearchPatternEdit::NotShowSize );
+  const bool notShowDate = ( options & MailCommon::SearchPatternEdit::NotShowDate );
+
   mFilterFieldList.clear();
-  mFilterFieldList.append( "" ); // empty entry for user input
+  mFilterFieldList.append( QString() ); // empty entry for user input
 
   if ( !headersOnly ) {
     mFilterFieldList.append( SpecialRuleFields[Message].getLocalizedDisplayName() );
@@ -338,10 +370,12 @@ void SearchRuleWidget::initFieldList( bool headersOnly, bool absoluteDates )
   }
   mFilterFieldList.append( SpecialRuleFields[AnyHeader].getLocalizedDisplayName() );
   mFilterFieldList.append( SpecialRuleFields[Recipients].getLocalizedDisplayName() );
-  mFilterFieldList.append( SpecialRuleFields[Size].getLocalizedDisplayName() );
+  if ( !notShowSize )
+    mFilterFieldList.append( SpecialRuleFields[Size].getLocalizedDisplayName() );
   if ( !absoluteDates ) {
     mFilterFieldList.append( SpecialRuleFields[AgeInDays].getLocalizedDisplayName() );
   }
+
   mFilterFieldList.append( SpecialRuleFields[Subject].getLocalizedDisplayName() );
   mFilterFieldList.append( SpecialRuleFields[From].getLocalizedDisplayName() );
   mFilterFieldList.append( SpecialRuleFields[To].getLocalizedDisplayName() );
@@ -350,15 +384,17 @@ void SearchRuleWidget::initFieldList( bool headersOnly, bool absoluteDates )
   mFilterFieldList.append( SpecialRuleFields[Tag].getLocalizedDisplayName() );
   mFilterFieldList.append( i18n( SpecialRuleFields[ReplyTo].displayName ) );
   mFilterFieldList.append( i18n( SpecialRuleFields[Organization].displayName ) );
-  mFilterFieldList.append( i18n( SpecialRuleFields[Date].displayName ) );
+
+  if ( !notShowDate )
+      mFilterFieldList.append( i18n( SpecialRuleFields[Date].displayName ) );
 
   // these others only represent message headers and you can add to
   // them as you like
-  mFilterFieldList.append( "List-Id" );
-  mFilterFieldList.append( "Resent-From" );
-  mFilterFieldList.append( "X-Loop" );
-  mFilterFieldList.append( "X-Mailing-List" );
-  mFilterFieldList.append( "X-Spam-Flag" );
+  mFilterFieldList.append( QLatin1String("List-Id") );
+  mFilterFieldList.append( QLatin1String("Resent-From") );
+  mFilterFieldList.append( QLatin1String("X-Loop") );
+  mFilterFieldList.append( QLatin1String("X-Mailing-List") );
+  mFilterFieldList.append( QLatin1String("X-Spam-Flag") );
 }
 
 void SearchRuleWidget::slotRuleFieldChanged( const QString &field )
@@ -373,19 +409,27 @@ void SearchRuleWidget::slotRuleFieldChanged( const QString &field )
 //
 //=============================================================================
 
-SearchRuleWidgetLister::SearchRuleWidgetLister( QWidget *parent, const char *,
-                                                bool headersOnly, bool absoluteDates )
+SearchRuleWidgetLister::SearchRuleWidgetLister( QWidget *parent, SearchPatternEdit::SearchPatternEditOptions options, SearchPatternEdit::SearchModeType modeType)
   : KWidgetLister( false, 2, FILTER_MAX_RULES, parent )
 {
   mRuleList = 0;
-  mHeadersOnly = headersOnly;
-  mAbsoluteDates = absoluteDates;
+
+  mTypeMode = modeType;
+  mOptions = options;
 }
 
 SearchRuleWidgetLister::~SearchRuleWidgetLister()
 {
 }
 
+void SearchRuleWidgetLister::setPatternEditOptions( SearchPatternEdit::SearchPatternEditOptions options )
+{
+    mOptions = options;
+    foreach ( QWidget *w, widgets() ) {
+        qobject_cast<SearchRuleWidget*>( w )->setPatternEditOptions( options );
+    }
+}
+
 void SearchRuleWidgetLister::setRuleList( QList<SearchRule::Ptr> *aList )
 {
   Q_ASSERT( aList );
@@ -481,13 +525,6 @@ void SearchRuleWidgetLister::updateAddRemoveButton()
   }
 }
 
-void SearchRuleWidgetLister::setHeadersOnly( bool headersOnly )
-{
-  foreach ( QWidget *w, widgets() ) {
-    qobject_cast<SearchRuleWidget*>( w )->setHeadersOnly( headersOnly );
-  }
-}
-
 void SearchRuleWidgetLister::reset()
 {
   if ( mRuleList ) {
@@ -502,7 +539,7 @@ void SearchRuleWidgetLister::reset()
 QWidget *SearchRuleWidgetLister::createWidget( QWidget *parent )
 {
   SearchRuleWidget *w =
-    new SearchRuleWidget( parent, SearchRule::Ptr(), mHeadersOnly, mAbsoluteDates );
+    new SearchRuleWidget( parent, SearchRule::Ptr(), mOptions, mTypeMode );
   reconnectWidget( w );
   return w;
 }
@@ -540,19 +577,30 @@ void SearchRuleWidgetLister::regenerateRuleListFromWidgets()
 //
 //=============================================================================
 
-SearchPatternEdit::SearchPatternEdit( QWidget *parent, SearchPatternEditOptions options )
+SearchPatternEdit::SearchPatternEdit( QWidget *parent, SearchPatternEditOptions options, SearchModeType modeType )
   : QWidget( parent ), mAllMessageRBtn( 0 )
 {
   setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed );
-  setObjectName( "SearchPatternEdit" );
-  initLayout( options );
+  setObjectName( QLatin1String("SearchPatternEdit") );
+  initLayout( options, modeType );
 }
 
 SearchPatternEdit::~SearchPatternEdit()
 {
 }
 
-void SearchPatternEdit::initLayout( SearchPatternEditOptions options )
+void SearchPatternEdit::updateSearchPattern()
+{
+  mRuleLister->regenerateRuleListFromWidgets();
+}
+
+void SearchPatternEdit::setPatternEditOptions( SearchPatternEdit::SearchPatternEditOptions options )
+{
+    mRuleLister->setPatternEditOptions(options);
+}
+
+
+void SearchPatternEdit::initLayout( SearchPatternEditOptions options, SearchModeType modeType )
 {
   QVBoxLayout *layout = new QVBoxLayout( this );
   layout->setMargin( 0 );
@@ -565,12 +613,12 @@ void SearchPatternEdit::initLayout( SearchPatternEditOptions options )
     mAllMessageRBtn = new QRadioButton( i18n( "Match all messages" ), this );
   }
 
-  mAllRBtn->setObjectName( "mAllRBtn" );
+  mAllRBtn->setObjectName( QLatin1String("mAllRBtn") );
   mAllRBtn->setChecked( true );
-  mAnyRBtn->setObjectName( "mAnyRBtn" );
+  mAnyRBtn->setObjectName( QLatin1String("mAnyRBtn") );
   mAnyRBtn->setChecked( false );
   if ( matchAllMessages ) {
-    mAllMessageRBtn->setObjectName( "mAllMessageRBtn" );
+    mAllMessageRBtn->setObjectName( QLatin1String("mAllMessageRBtn") );
     mAllMessageRBtn->setChecked(false);
   }
   layout->addWidget( mAllRBtn );
@@ -593,10 +641,7 @@ void SearchPatternEdit::initLayout( SearchPatternEditOptions options )
   //------------the list of SearchRuleWidget's
   mRuleLister =
     new SearchRuleWidgetLister(
-      this,
-      "swl",
-      ( options & MailCommon::SearchPatternEdit::HeadersOnly ),
-      ( options & MailCommon::SearchPatternEdit::AbsoluteDate ) );
+      this, options, modeType);
 
   mRuleLister->slotClear();
 
@@ -646,12 +691,6 @@ void SearchPatternEdit::setSearchPattern( SearchPattern *aPattern )
   emit patternChanged();
 }
 
-void SearchPatternEdit::setHeadersOnly( bool headersOnly )
-{
-  mRuleLister->setHeadersOnly( headersOnly );
-  emit patternChanged();
-}
-
 void SearchPatternEdit::reset()
 {
   mRuleLister->reset();
