@@ -28,8 +28,8 @@
 #include "messagecomposer/composer/composer.h"
 
 #include "messagecomposer/part/globalpart.h"
-#include "messageviewer/editorwatcher.h"
-#include "messageviewer/nodehelper.h"
+#include "messageviewer/viewer/editorwatcher.h"
+#include "messageviewer/viewer/nodehelper.h"
 #include "messageviewer/utils/util.h"
 
 #include <akonadi/itemfetchjob.h>
@@ -62,7 +62,7 @@
 #include <messagecore/attachment/attachmentfrommimecontentjob.h>
 #include <messagecore/attachment/attachmentfromurljob.h>
 #include <messagecore/attachment/attachmentpropertiesdialog.h>
-#include <messagecomposersettings.h>
+#include <settings/messagecomposersettings.h>
 #include <KIO/Job>
 
 #include <KMime/Content>
