@@ -26,6 +26,9 @@
 #include "autocorrection/composerautocorrection.h"
 #include "settings/messagecomposersettings.h"
 
+#include <kmacroexpander.h>
+#include <KShell>
+
 
 #include <grantlee/plaintextmarkupbuilder.h>
 
@@ -147,59 +150,17 @@ void KMeditorPrivate::startExternalEditor()
   mExtEditorProcess = new KProcess();
   // construct command line...
   const QString commandLine = extEditorPath.trimmed();
-  QStringList command;
-  bool doubleQuoteFound = false;
+  QHash<QChar,QString> map;
+  map.insert(QLatin1Char('l'), QString::number(q->textCursor().blockNumber() + 1));
+  map.insert(QLatin1Char('w'), QString::number((qulonglong)q->winId()));
+  map.insert(QLatin1Char('f'), mExtEditorTempFile->fileName());
+  const QString cmd = KMacroExpander::expandMacrosShellQuote(commandLine, map);
+  const QStringList arg = KShell::splitArgs(cmd);
   bool filenameAdded = false;
-  QString arg;
-  const int commandLineLength( commandLine.length() );
-  for(int i = 0; i < commandLineLength; ++i) {
-    const QChar letter( commandLine.at(i) );
-    if ( doubleQuoteFound ) {
-      if ( letter != QLatin1Char('"') ) {
-        arg.append(letter);
-      } else {
-        doubleQuoteFound = false;
-        command<<arg;
-        arg.clear();
-      }
-    } else {
-      if( letter == QLatin1Char('%') ) { //Be safe
-        if ( i+1 >= commandLineLength ) {
-          arg.append( letter );
-          command<<arg;
-          arg.clear();
-          break;
-        }
-        //Example emacs --parent-id=<number>
-        if(!arg.isEmpty()) {
-         command<<arg;
-         arg.clear();
-        }
-        ++i; //look at next char
-        const QChar nextChar(commandLine.at(i));
-        if( nextChar == QLatin1Char('f') ) {
-          filenameAdded = true;
-          command<<mExtEditorTempFile->fileName();
-        } else if( nextChar == QLatin1Char('l') ) {
-          command<<QString::number(q->textCursor().blockNumber() + 1);  // line number
-        } else if( nextChar == QLatin1Char('w') ) { //Window id
-          command<<QString::number((qulonglong)q->winId());
-        } else {
-          arg.append( letter );
-          arg.append( commandLine.at(i) );
-        }
-      } else if( letter == QLatin1Char('"') ) {
-        doubleQuoteFound = true;
-      } else if( letter == QLatin1Char(' ') ) {
-          if ( !arg.isEmpty() ) {
-            command<<arg;
-            arg.clear();
-          }
-      } else {
-        arg.append( letter );
-      }
-    }
+  if (commandLine.contains(QLatin1String("%f"))) {
+      filenameAdded = true;
   }
+  QStringList command;
   if ( !arg.isEmpty() )
     command<<arg;
   ( *mExtEditorProcess ) << command;
@@ -211,7 +172,7 @@ void KMeditorPrivate::startExternalEditor()
                     q, SLOT(slotEditorFinished(int,QProcess::ExitStatus)) );
   mExtEditorProcess->start();
   if ( !mExtEditorProcess->waitForStarted() ) {
-    KMessageBox::error(q->topLevelWidget(),i18n("External editor can not be started. Please verify command \"%1\"",commandLine));
+    KMessageBox::error(q->topLevelWidget(),i18n("External editor cannot be started. Please verify command \"%1\"",commandLine));
     mExtEditorProcess->deleteLater();
     mExtEditorProcess = 0;
     delete mExtEditorTempFile;
@@ -253,6 +214,12 @@ void KMeditor::startExternalEditor()
     }
 }
 
+static bool isSpecial( const QTextCharFormat &charFormat )
+{
+    return charFormat.isFrameFormat() || charFormat.isImageFormat() ||
+            charFormat.isListFormat() || charFormat.isTableFormat() || charFormat.isTableCellFormat();
+}
+
 void KMeditor::keyPressEvent ( QKeyEvent *e )
 {
   if ( d->useExtEditor &&
@@ -285,13 +252,13 @@ void KMeditor::keyPressEvent ( QKeyEvent *e )
         const bool richText = (textMode() == KRichTextEdit::Rich);
         d->mAutoCorrection->autocorrect(richText, *document(),textCursor().position());
         if (e->key() == Qt::Key_Space) {
-            if (richText && !initialTextFormat.isImageFormat())
+            if (richText && !isSpecial(initialTextFormat))
                 textCursor().insertText(QLatin1String(" "), initialTextFormat);
             else
                 textCursor().insertText(QLatin1String(" "));
           return;
         } else {
-            if (richText && !initialTextFormat.isImageFormat())
+            if (richText && !isSpecial(initialTextFormat))
                 textCursor().insertText(QLatin1String("\n"), initialTextFormat);
             else
                 textCursor().insertText(QLatin1String("\n"));
