@@ -124,7 +124,7 @@ MessageFactory::MessageReply MessageFactory::createReply()
           if ( m_mailingListAddresses.isEmpty() )
             replyAll = false;
         } else if ( !m_mailingListAddresses.isEmpty() ) {
-          toList = (KMime::Types::Mailbox::List() << m_mailingListAddresses[ 0 ]);
+          toList = (KMime::Types::Mailbox::List() << m_mailingListAddresses.at( 0 ));
         } else {
 
           // doesn't seem to be a mailing list, reply to From: address
@@ -494,8 +494,8 @@ KMime::Message::Ptr MessageFactory::createRedirect( const QString &toStr, int tr
   msg->parse();
 
   uint id = identity;
-  if(id == -1) {
-    QString strId = msg->headerByType( "X-KMail-Identity" ) ? msg->headerByType( "X-KMail-Identity" )->asUnicodeString().trimmed() : QString::fromLocal8Bit("");
+  if(identity == -1) {
+    const QString strId = msg->headerByType( "X-KMail-Identity" ) ? msg->headerByType( "X-KMail-Identity" )->asUnicodeString().trimmed() : QString::fromLocal8Bit("");
     if ( !strId.isEmpty())
       id = strId.toUInt();
   }
