@@ -25,7 +25,7 @@
 #include <KDebug>
 #include <qtest_kde.h>
 
-#include <messagecore/attachmentpart.h>
+#include <messagecore/attachment/attachmentpart.h>
 #include <boost/shared_ptr.hpp>
 using namespace MessageCore;
 
