@@ -56,6 +56,7 @@ public:
       mActionMenu( 0 ),
       mModel( 0 ),
       mSelectionModel( 0 ),
+      mPreSelectionMode( Core::PreSelectLastSelected ),
       mNewTabButton( 0 ),
       mCloseTabButton( 0 ),
       mCloseTabAction( 0 ),
@@ -93,6 +94,7 @@ public:
 
   QAbstractItemModel *mModel;
   QItemSelectionModel *mSelectionModel;
+  Core::PreSelectionMode mPreSelectionMode;
 
   QHash<Widget*, QItemSelectionModel*> mWidgetSelectionHash;
   QList<const QAbstractProxyModel*> mProxyStack;
@@ -114,7 +116,7 @@ using namespace Akonadi;
 using namespace MessageList;
 
 
-Pane::Pane( QAbstractItemModel *model, QItemSelectionModel *selectionModel, QWidget *parent )
+Pane::Pane( bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *selectionModel, QWidget *parent )
   : KTabWidget( parent ), d( new Private( this ) )
 {
   setDocumentMode( true );
@@ -165,7 +167,7 @@ Pane::Pane( QAbstractItemModel *model, QItemSelectionModel *selectionModel, QWid
   setTabsClosable( Core::Settings::self()->tabsHaveCloseButton() );
   connect( this, SIGNAL(closeRequest(QWidget*)), SLOT(closeTab(QWidget*)) );
 
-  readConfig();
+  readConfig(restoreSession);
   setMovable( true );
 
   connect( d->mSelectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
@@ -190,7 +192,7 @@ Pane::Pane( QAbstractItemModel *model, QItemSelectionModel *selectionModel, QWid
 
 Pane::~Pane()
 {
-  writeConfig();
+  writeConfig(true);
   delete d;
 }
 
@@ -449,6 +451,9 @@ void Pane::Private::onSelectionChanged( const QItemSelection &selected, const QI
 
   // Deselect old before we select new - so that the messagelist can clear first.
   s->select( mapSelectionToSource( deselected ), QItemSelectionModel::Deselect );
+  if ( s->selection().isEmpty() ) {
+      w->view()->model()->setPreSelectionMode( mPreSelectionMode );
+  }
   s->select( mapSelectionToSource( selected ), QItemSelectionModel::Select );
 
   QString label;
@@ -673,6 +678,7 @@ MessageList::StorageModel *Pane::createStorageModel( QAbstractItemModel *model,
 
 void Pane::setCurrentFolder( const Akonadi::Collection &collection, bool, Core::PreSelectionMode preSelectionMode, const QString &overrideLabel )
 {
+  d->mPreSelectionMode = preSelectionMode;
   Widget *w = static_cast<Widget*>( currentWidget() );
   if ( w ) {
     w->setCurrentFolder( collection );
@@ -836,6 +842,16 @@ QList<Akonadi::Item> Pane::selectionAsMessageItemList( bool includeCollapsedChil
   return w->selectionAsMessageItemList( includeCollapsedChildren );
 }
 
+QList<Akonadi::Item::Id> Pane::selectionAsListMessageId( bool includeCollapsedChildren ) const
+{
+  Widget *w = static_cast<Widget*>( currentWidget() );
+  if ( w == 0 ) {
+    return QList<Akonadi::Item::Id>();
+  }
+  return w->selectionAsListMessageId( includeCollapsedChildren );
+}
+
+
 QVector<qlonglong> Pane::selectionAsMessageItemListId( bool includeCollapsedChildren ) const
 {
   Widget *w = static_cast<Widget*>( currentWidget() );
@@ -1002,7 +1018,7 @@ void Pane::updateTagComboBox()
   }
 }
 
-void Pane::writeConfig()
+void Pane::writeConfig(bool restoreSession)
 {
   KConfigGroup conf( MessageList::Core::Settings::self()->config(),"MessageListPane");
 
@@ -1012,22 +1028,24 @@ void Pane::writeConfig()
     conf.deleteGroup( group );
   }
 
-  conf.writeEntry(QLatin1String("currentIndex"),currentIndex());
-  conf.writeEntry(QLatin1String("tabNumber"),count());
+  if (restoreSession) {
+    conf.writeEntry(QLatin1String("currentIndex"),currentIndex());
+    conf.writeEntry(QLatin1String("tabNumber"),count());
 
-  for ( int i=0; i<count(); ++i ) {
-    Widget *w = qobject_cast<Widget *>( widget( i ) );
-    KConfigGroup grp(MessageList::Core::Settings::self()->config(),QString::fromLatin1("MessageListTab%1").arg(i));
-    grp.writeEntry(QLatin1String("collectionId"),w->currentCollection().id());
-    grp.writeEntry(QLatin1String("HeaderState"), w->view()->header()->saveState());
+    for ( int i=0; i<count(); ++i ) {
+      Widget *w = qobject_cast<Widget *>( widget( i ) );
+      KConfigGroup grp(MessageList::Core::Settings::self()->config(),QString::fromLatin1("MessageListTab%1").arg(i));
+      grp.writeEntry(QLatin1String("collectionId"),w->currentCollection().id());
+      grp.writeEntry(QLatin1String("HeaderState"), w->view()->header()->saveState());
+    }
   }
   conf.sync();
 }
 
 
-void Pane::readConfig()
+void Pane::readConfig(bool restoreSession)
 {
-  if(MessageList::Core::Settings::self()->config()->hasGroup(QLatin1String("MessageListPane"))) {
+  if(restoreSession && MessageList::Core::Settings::self()->config()->hasGroup(QLatin1String("MessageListPane"))) {
     KConfigGroup conf( MessageList::Core::Settings::self()->config(),"MessageListPane");
     const int numberOfTab = conf.readEntry(QLatin1String("tabNumber"),0);
     if(numberOfTab == 0) {
@@ -1036,7 +1054,6 @@ void Pane::readConfig()
       for(int i = 0; i<numberOfTab; ++i) {
         KConfigGroup grp(MessageList::Core::Settings::self()->config(),QString::fromLatin1("MessageListTab%1").arg(i));
         QItemSelectionModel *selectionModel = createNewTab();
-        Q_UNUSED( selectionModel );
 #if 0
         Akonadi::Collection::Id id = grp.readEntry(QLatin1String("collectionId"),-1);
         ETMViewStateSaver *saver = new ETMViewStateSaver;
@@ -1047,7 +1064,10 @@ void Pane::readConfig()
             saver->setSelectionModel(selectionModel);
             saver->restoreState( grp );
             saver->selectCollections(Akonadi::Collection::List()<<Akonadi::Collection(id));
+            saver->restoreCurrentItem( QString::fromLatin1("c%1").arg(id) );
         }
+#else
+        Q_UNUSED( selectionModel );
 #endif
         Widget *w = qobject_cast<Widget *>( widget( i ) );
         w->view()->header()->restoreState(grp.readEntry(QLatin1String("HeaderState"),QByteArray()));
