@@ -70,12 +70,13 @@ public:
   /**
    * Create a Pane wrapping the specified model and selection.
    */
-  explicit Pane( QAbstractItemModel *model, QItemSelectionModel *selectionModel, QWidget *parent = 0 );
+  explicit Pane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *selectionModel, QWidget *parent = 0 );
   ~Pane();
 
 
   virtual MessageList::StorageModel *createStorageModel( QAbstractItemModel *model, QItemSelectionModel *selectionModel, QObject *parent );
 
+  virtual void writeConfig(bool restoreSession);
 
   /**
    * Sets the XML GUI client which the pane is used in.
@@ -139,6 +140,8 @@ public:
    */
   QVector<qlonglong> selectionAsMessageItemListId( bool includeCollapsedChildren = true ) const;
 
+  QList<Akonadi::Item::Id> selectionAsListMessageId( bool includeCollapsedChildren = true) const;
+
   /**
    * Returns the Akonadi::Item bound to the current StorageModel that
    * are part of the current thread. The current thread is the thread
@@ -385,9 +388,6 @@ public:
 
   void updateTagComboBox();
 
-  void writeConfig();
-
-  void readConfig();
 
   bool searchEditHasFocus() const;
 
@@ -456,7 +456,12 @@ signals:
   void currentTabChanged();
 
 
+
 private:
+
+
+  void readConfig(bool restoreSession);
+
   Q_PRIVATE_SLOT(d, void onSelectionChanged( const QItemSelection&, const QItemSelection& ))
   Q_PRIVATE_SLOT(d, void onNewTabClicked())
   Q_PRIVATE_SLOT(d, void onCloseTabClicked())
