@@ -17,6 +17,7 @@
 
 #include "scamdetection.h"
 #include "scamdetectiondetailsdialog.h"
+#include "scamcheckshorturl.h"
 #include "settings/globalsettings.h"
 
 #include <QWebElement>
@@ -32,7 +33,8 @@ static QString addWarningColor(const QString &url)
 }
 
 ScamDetection::ScamDetection(QObject *parent)
-    : QObject(parent)
+    : QObject(parent),
+      mCheckShortUrl(new ScamCheckShortUrl(this))
 {
 }
 
@@ -40,6 +42,11 @@ ScamDetection::~ScamDetection()
 {
 }
 
+ScamCheckShortUrl *ScamDetection::scamCheckShortUrl() const
+{
+    return mCheckShortUrl;
+}
+
 void ScamDetection::scanPage(QWebFrame *frame)
 {
     if (GlobalSettings::self()->scamDetectionEnabled()) {
@@ -80,8 +87,8 @@ bool ScamDetection::scanFrame(const QWebElement &rootElement, QString &details)
                 if (title.startsWith(QLatin1String("www."))) {
                     const QString completUrl =  url.scheme() + QLatin1String("://") + title;
                     if ( completUrl != href &&
-                        href != (completUrl + QLatin1Char('/'))){
-                       foundScam = true;
+                         href != (completUrl + QLatin1Char('/'))) {
+                        foundScam = true;
                     }
                 } else {
                     if (href != title) {
@@ -114,6 +121,13 @@ bool ScamDetection::scanFrame(const QWebElement &rootElement, QString &details)
                 foundScam = true;
             }
         }
+        //Check shortUrl
+        if (!foundScam) {
+            if (ScamCheckShortUrl::isShortUrl(url)) {
+                details += QLatin1String("<li>") + i18n("This email contains a shorturl (%1). It can redirect to another server.", addWarningColor(url.toString())) + QLatin1String("</li>");
+                foundScam = true;
+            }
+        }
     }
     //3) has form
     if (rootElement.findAll(QLatin1String("form")).count() > 0) {
@@ -126,13 +140,10 @@ bool ScamDetection::scanFrame(const QWebElement &rootElement, QString &details)
 
 void ScamDetection::showDetails()
 {
-    if (mDetailsDialog) {
-        mDetailsDialog->setDetails(mDetails);
-        mDetailsDialog->show();
-        return;
+    if (!mDetailsDialog) {
+        mDetailsDialog = new MessageViewer::ScamDetectionDetailsDialog;
     }
 
-    mDetailsDialog = new MessageViewer::ScamDetectionDetailsDialog;
     mDetailsDialog->setDetails(mDetails);
     mDetailsDialog->show();
 }
