@@ -1,4 +1,5 @@
-/* Copyright 2010 Thomas McGuire <mcguire@kde.org>
+/*
+   Copyright 2010 Thomas McGuire <mcguire@kde.org>
 
    Copyright 2013 Laurent Montel <monte@kde.org>
 
@@ -20,6 +21,9 @@
 */
 #include "mailwebview.h"
 #include "scamdetection/scamdetection.h"
+#include "scamdetection/scamcheckshorturl.h"
+#include "adblock/adblockblockableitemsdialog.h"
+#include "adblock/webpage.h"
 
 #include <KDebug>
 #include <KActionCollection>
@@ -98,7 +102,7 @@ static bool isEditableElement(QWebPage* page)
         && (type.isEmpty() || type == QLatin1String("text") || type == QLatin1String("password"))) {
        return true;
      }
-     if (element.evaluateJavaScript("this.isContentEditable").toBool()) {
+     if (element.evaluateJavaScript(QLatin1String("this.isContentEditable")).toBool()) {
        return true;
      }
   }
@@ -123,8 +127,11 @@ static void handleDuplicateLinkElements(const QWebElement& element, QHash<QStrin
 
 
 MailWebView::MailWebView( KActionCollection *actionCollection, QWidget *parent )
-    : SuperClass( parent ), mScamDetection(new ScamDetection), mActionCollection(actionCollection)
+    : SuperClass( parent, false ),
+      mScamDetection(new ScamDetection),
+      mActionCollection(actionCollection)
 {
+  setPage(new MessageViewer::WebPage(this));
   page()->setLinkDelegationPolicy( QWebPage::DelegateAllLinks );
   settings()->setAttribute( QWebSettings::JavascriptEnabled, false );
   settings()->setAttribute( QWebSettings::JavaEnabled, false );
@@ -257,7 +264,7 @@ static bool has_parent_div_with_id( const QWebElement & start, const QString & i
     return false;
 
   if ( start.tagName().toLower() == QLatin1String("div") ) {
-    if ( start.attribute( "id", "" ) == id )
+      if ( start.attribute( QLatin1String("id"), QString() ) == id )
       return true;
   }
 
@@ -269,14 +276,14 @@ bool MailWebView::isAttachmentInjectionPoint( const QPoint & global ) const
   // for QTextBrowser, can be implemented as 'return false'
   const QPoint local = page()->view()->mapFromGlobal( global );
   const QWebHitTestResult hit = page()->currentFrame()->hitTestContent( local );
-  return has_parent_div_with_id( hit.enclosingBlockElement(), "attachmentInjectionPoint" );
+  return has_parent_div_with_id( hit.enclosingBlockElement(), QLatin1String("attachmentInjectionPoint") );
 }
 
 void MailWebView::injectAttachments( const function<QString()> & delayedHtml )
 {
   // for QTextBrowser, can be implemented empty
   QWebElement doc = page()->currentFrame()->documentElement();
-  QWebElement injectionPoint = doc.findFirst( "*#attachmentInjectionPoint" );
+  QWebElement injectionPoint = doc.findFirst( QLatin1String("*#attachmentInjectionPoint") );
   if( injectionPoint.isNull() )
     return;
 
@@ -284,14 +291,14 @@ void MailWebView::injectAttachments( const function<QString()> & delayedHtml )
   if ( html.isEmpty() )
     return;
 
-  assert( injectionPoint.tagName().toLower() == "div" );
+  assert( injectionPoint.tagName().toLower() == QLatin1String("div") );
   injectionPoint.setInnerXml( html );
 }
 
 void MailWebView::scrollToAnchor( const QString & anchor )
 {
   QWebElement doc = page()->mainFrame()->documentElement();
-  QWebElement link = doc.findFirst( "a[name=" + anchor +']' );
+  QWebElement link = doc.findFirst( QLatin1String("a[name=") + anchor +QLatin1Char(']') );
   if ( link.isNull() ) {
     return;
   }
@@ -306,19 +313,19 @@ void MailWebView::scrollToAnchor( const QString & anchor )
 bool MailWebView::removeAttachmentMarking( const QString & id )
 {
   QWebElement doc = page()->mainFrame()->documentElement();
-  QWebElement attachmentDiv = doc.findFirst( "*#" + id );
+  QWebElement attachmentDiv = doc.findFirst( QLatin1String("*#") + id );
   if ( attachmentDiv.isNull() )
     return false;
-  attachmentDiv.removeAttribute( "style" );
+  attachmentDiv.removeAttribute( QLatin1String("style") );
   return true;
 }
 
 void MailWebView::markAttachment( const QString & id, const QString & style )
 {
   QWebElement doc = page()->mainFrame()->documentElement();
-  QWebElement attachmentDiv = doc.findFirst( "*#" + id );
+  QWebElement attachmentDiv = doc.findFirst( QLatin1String("*#") + id );
   if ( !attachmentDiv.isNull() ) {
-    attachmentDiv.setAttribute( "style", style );
+    attachmentDiv.setAttribute(QLatin1String( "style"), style );
   }
 }
 
@@ -367,7 +374,7 @@ Qt::ScrollBarPolicy MailWebView::scrollBarPolicy( Qt::Orientation orientation )
 bool MailWebView::replaceInnerHtml( const QString & id, const function<QString()> & delayedHtml )
 {
   QWebElement doc = page()->currentFrame()->documentElement();
-  QWebElement tag = doc.findFirst( "*#" + id );
+  QWebElement tag = doc.findFirst( QLatin1String("*#") + id );
   if ( tag.isNull() ) {
     return false;
   }
@@ -378,13 +385,13 @@ bool MailWebView::replaceInnerHtml( const QString & id, const function<QString()
 void MailWebView::setElementByIdVisible( const QString & id, bool visible )
 {
   QWebElement doc = page()->currentFrame()->documentElement();
-  QWebElement e = doc.findFirst( "*#" + id );
+  QWebElement e = doc.findFirst( QLatin1String("*#") + id );
   Q_ASSERT( !e.isNull() );
 
   if ( visible ) {
-    e.removeAttribute( "display" );
+    e.removeAttribute( QLatin1String("display") );
   } else {
-    e.setStyleProperty( "display", "none" );
+    e.setStyleProperty( QLatin1String("display"), QLatin1String("none") );
   }
 }
 
@@ -645,4 +652,24 @@ void MailWebView::saveMainFrameScreenshotInFile(const QString &filename)
     image.save(filename);
 }
 
+void MailWebView::openBlockableItemsDialog()
+{
+    QPointer<AdBlockBlockableItemsDialog> dlg = new AdBlockBlockableItemsDialog(this);
+    dlg->setWebFrame(page()->mainFrame());
+    if (dlg->exec()) {
+        dlg->saveFilters();
+    }
+    delete dlg;
+}
+
+void MailWebView::expandUrl(const KUrl &url)
+{
+    mScamDetection->scamCheckShortUrl()->expandedUrl(url);
+}
+
+bool MailWebView::isAShortUrl(const KUrl &url) const
+{
+    return mScamDetection->scamCheckShortUrl()->isShortUrl(url);
+}
+
 #include "mailwebview.moc"
