@@ -32,6 +32,7 @@
 #include "settings/globalsettings.h"
 #include "viewer/mailwebview.h"
 #include "viewer/mimetreemodel.h"
+#include "adblock/adblockmanager.h"
 
 #include <akonadi/kmime/messageparts.h>
 #include <akonadi/itemfetchjob.h>
@@ -655,6 +656,35 @@ void Viewer::saveMainFrameScreenshotInFile(const QString &filename)
     return d->saveMainFrameScreenshotInFile(filename);
 }
 
+KAction *Viewer::blockImage()
+{
+    Q_D( Viewer );
+    return d->mBlockImage;
+}
+
+bool Viewer::adblockEnabled() const
+{
+    return MessageViewer::AdBlockManager::self()->isEnabled();
+}
+
+KAction *Viewer::openBlockableItems()
+{
+    Q_D( Viewer );
+    return d->mBlockableItems;
+}
+
+bool Viewer::isAShortUrl(const KUrl &url) const
+{
+    Q_D( const Viewer );
+    return d->isAShortUrl(url);
+}
+
+KAction *Viewer::expandShortUrlAction()
+{
+    Q_D( Viewer );
+    return d->mExpandUrlAction;
+}
+
 }
 
 #include "viewer.moc"
