@@ -146,7 +146,7 @@ QML_DECLARE_TYPE( EventViews::TimelineViewItem )
 EventViews::PrefsPtr MainView::m_calendarPrefs;
 
 MainView::MainView( QWidget* parent )
-  : KDeclarativeMainView( "korganizer-mobile", new EventListProxy, parent ),
+  : KDeclarativeMainView( QLatin1String("korganizer-mobile"), new EventListProxy, parent ),
     m_identityManager( 0 ),
     m_changer( 0 ),
     mActionManager( 0 )
@@ -190,7 +190,7 @@ void MainView::doDelayedInit()
 
   m_calendar = Akonadi::ETMCalendar::Ptr( new Akonadi::ETMCalendar() );
   m_calendar->setWeakPointer( m_calendar );
-  engine()->rootContext()->setContextProperty( "calendarModel", QVariant::fromValue( static_cast<QObject*>( m_calendar.data() ) ) );
+  engine()->rootContext()->setContextProperty( QLatin1String("calendarModel"), QVariant::fromValue( static_cast<QObject*>( m_calendar.data() ) ) );
   Akonadi::FreeBusyManager::self()->setCalendar( m_calendar );
 
   // TODO: set a groupware delegate to handle counter proposals
@@ -205,7 +205,7 @@ void MainView::doDelayedInit()
   collectionselection = new CalendarSupport::CollectionSelection( regularSelectionModel(), this );
   EventViews::EventView::setGlobalCollectionSelection( collectionselection );
 
-  QDBusConnection::sessionBus().registerService( "org.kde.korganizer" ); //register also as the real korganizer, so kmail can communicate with it
+  QDBusConnection::sessionBus().registerService( QLatin1String("org.kde.korganizer") ); //register also as the real korganizer, so kmail can communicate with it
 
   KAction *action = new KAction( i18n( "Import Events" ), this );
   connect( action, SIGNAL(triggered(bool)), SLOT(importItems()) );
@@ -277,7 +277,7 @@ void MainView::doDelayedInit()
   //register DBUS interface
   m_calendarIface = new CalendarInterface( this );
   new CalendarAdaptor( m_calendarIface );
-  QDBusConnection::sessionBus().registerObject( "/Calendar", m_calendarIface );
+  QDBusConnection::sessionBus().registerObject( QLatin1String("/Calendar"), m_calendarIface );
 
   KPIM::ReminderClient::startDaemon();
 }
@@ -519,7 +519,7 @@ void MainView::setupStandardActionManager( QItemSelectionModel *collectionSelect
   mActionManager->action( StandardActionManager::MoveCollectionToDialog )->setText( i18n( "Move Calendar To" ) );
   mActionManager->action( StandardActionManager::CopyCollectionToDialog )->setText( i18n( "Copy Calendar To" ) );
 
-  actionCollection()->action( "synchronize_all_items" )->setText( i18n( "Synchronize All Accounts" ) );
+  actionCollection()->action( QLatin1String("synchronize_all_items") )->setText( i18n( "Synchronize All Accounts" ) );
 
   const QStringList pages = QStringList() << QLatin1String( "CalendarSupport::CollectionGeneralPage" )
                                           << QLatin1String( "Akonadi::CachePolicyPage" );
@@ -537,23 +537,23 @@ void MainView::updateActionTexts()
   const Akonadi::Item item = items.first();
   const QString mimeType = item.mimeType();
   if ( mimeType == KCalCore::Event::eventMimeType() ) {
-    actionCollection()->action( "akonadi_item_copy" )->setText( ki18np( "Copy Event", "Copy %1 Events" ).subs( itemCount ).toString() );
-    actionCollection()->action( "akonadi_item_copy_to_dialog" )->setText( i18n( "Copy Event To" ) );
-    actionCollection()->action( "akonadi_item_delete" )->setText( ki18np( "Delete Event", "Delete %1 Events" ).subs( itemCount ).toString() );
-    actionCollection()->action( "akonadi_item_move_to_dialog" )->setText( i18n( "Move Event To" ) );
-    actionCollection()->action( "akonadi_incidence_edit" )->setText( i18n( "Edit Event" ) );
+    actionCollection()->action( QLatin1String("akonadi_item_copy") )->setText( ki18np( "Copy Event", "Copy %1 Events" ).subs( itemCount ).toString() );
+    actionCollection()->action( QLatin1String("akonadi_item_copy_to_dialog") )->setText( i18n( "Copy Event To" ) );
+    actionCollection()->action( QLatin1String("akonadi_item_delete") )->setText( ki18np( "Delete Event", "Delete %1 Events" ).subs( itemCount ).toString() );
+    actionCollection()->action( QLatin1String("akonadi_item_move_to_dialog") )->setText( i18n( "Move Event To" ) );
+    actionCollection()->action( QLatin1String("akonadi_incidence_edit") )->setText( i18n( "Edit Event" ) );
   } else if ( mimeType == KCalCore::Todo::todoMimeType() ) {
-    actionCollection()->action( "akonadi_item_copy" )->setText( ki18np( "Copy Task", "Copy %1 Tasks" ).subs( itemCount ).toString() );
-    actionCollection()->action( "akonadi_item_copy_to_dialog" )->setText( i18n( "Copy Task To" ) );
-    actionCollection()->action( "akonadi_item_delete" )->setText( ki18np( "Delete Task", "Delete %1 Tasks" ).subs( itemCount ).toString() );
-    actionCollection()->action( "akonadi_item_move_to_dialog" )->setText( i18n( "Move Task To" ) );
-    actionCollection()->action( "akonadi_incidence_edit" )->setText( i18n( "Edit Task" ) );
+    actionCollection()->action( QLatin1String("akonadi_item_copy") )->setText( ki18np( "Copy Task", "Copy %1 Tasks" ).subs( itemCount ).toString() );
+    actionCollection()->action(QLatin1String( "akonadi_item_copy_to_dialog") )->setText( i18n( "Copy Task To" ) );
+    actionCollection()->action( QLatin1String("akonadi_item_delete") )->setText( ki18np( "Delete Task", "Delete %1 Tasks" ).subs( itemCount ).toString() );
+    actionCollection()->action( QLatin1String("akonadi_item_move_to_dialog") )->setText( i18n( "Move Task To" ) );
+    actionCollection()->action( QLatin1String("akonadi_incidence_edit") )->setText( i18n( "Edit Task" ) );
   } else if ( mimeType == KCalCore::Journal::journalMimeType() ) {
-    actionCollection()->action( "akonadi_item_copy" )->setText( ki18np( "Copy Journal", "Copy %1 Journals" ).subs( itemCount ).toString() );
-    actionCollection()->action( "akonadi_item_copy_to_dialog" )->setText( i18n( "Copy Journal To" ) );
-    actionCollection()->action( "akonadi_item_delete" )->setText( ki18np( "Delete Journal", "Delete %1 Journals" ).subs( itemCount ).toString() );
-    actionCollection()->action( "akonadi_item_move_to_dialog" )->setText( i18n( "Move Journal To" ) );
-    actionCollection()->action( "akonadi_incidence_edit" )->setText( i18n( "Edit Journal" ) );
+    actionCollection()->action( QLatin1String("akonadi_item_copy") )->setText( ki18np( "Copy Journal", "Copy %1 Journals" ).subs( itemCount ).toString() );
+    actionCollection()->action( QLatin1String("akonadi_item_copy_to_dialog") )->setText( i18n( "Copy Journal To" ) );
+    actionCollection()->action( QLatin1String("akonadi_item_delete") )->setText( ki18np( "Delete Journal", "Delete %1 Journals" ).subs( itemCount ).toString() );
+    actionCollection()->action( QLatin1String("akonadi_item_move_to_dialog" ))->setText( i18n( "Move Journal To" ) );
+    actionCollection()->action( QLatin1String("akonadi_incidence_edit") )->setText( i18n( "Edit Journal" ) );
   }
 }
 
