@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -22,6 +22,8 @@
 
 #include <QPlainTextEdit>
 
+namespace Sonnet {
+}
 namespace PimCommon {
 class PIMCOMMON_EXPORT PlainTextEditor : public QPlainTextEdit
 {
@@ -34,18 +36,21 @@ public:
     void setSearchSupport(bool b);
     bool searchSupport() const;
 
+    bool checkSpellingEnabled() const;
+    void setCheckSpellingEnabled( bool check );
+
     bool spellCheckingSupport() const;
     void setSpellCheckingSupport( bool check );
 
-    virtual void setReadOnly( bool readOnly );
+    void setSpellCheckingLanguage(const QString &_language);
+    const QString& spellCheckingLanguage() const;
 
-public slots:
-    void slotDisplayMessageIndicator(const QString &message);
-    void slotCheckSpelling();
-    void slotSpeakText();
+    virtual void setReadOnly( bool readOnly );
 
 private Q_SLOTS:
     void slotUndoableClear();
+    void slotSpeakText();
+    void slotCheckSpelling();
     void slotSpellCheckerMisspelling( const QString &text, int pos );
     void slotSpellCheckerCorrected( const QString &, int,const QString &);
     void slotSpellCheckerAutoCorrect(const QString&, const QString&);
@@ -53,15 +58,12 @@ private Q_SLOTS:
     void slotSpellCheckerFinished();
 
 protected:
-    virtual void addExtraMenuEntry(QMenu *menu, const QPoint &pos);
+    virtual void addExtraMenuEntry(QMenu *menu);
 
 protected:
     void contextMenuEvent( QContextMenuEvent *event );
     void wheelEvent( QWheelEvent *event );
-    bool event(QEvent* ev);    
-    void keyPressEvent(QKeyEvent *event);
-    bool overrideShortcut(const QKeyEvent* event);
-    bool handleShortcut(const QKeyEvent *event);
+    bool event(QEvent* ev);
 
 Q_SIGNALS:
     void findText();
@@ -72,6 +74,7 @@ Q_SIGNALS:
     void spellCheckStatus(const QString &);
 
 private:
+    bool overrideShortcut(const QKeyEvent* event);
     void deleteWordBack();
     void deleteWordForward();
     void highlightWord( int length, int pos );
