@@ -20,6 +20,7 @@
 
 #include "utils.h"
 #include <Akonadi/Collection>
+#include <QStringList>
 
 class QWidget;
 class QProgressDialog;
@@ -50,11 +51,17 @@ public:
 
     bool wasCanceled() const;
 
+    static int archiveVersion();
+    static void setArchiveVersion(int version);
+
 Q_SIGNALS:
     void info(const QString &);
     void error(const QString &);
+    void title(const QString &);
+    void endLine();
 
 protected:
+    void infoAboutNewResource(const QString &resourceName);
     void copyToDirectory(const KArchiveEntry *entry, const QString &dest);
     void extractZipFile(const KArchiveFile *file, const QString &source, const QString &destination);
 
@@ -69,9 +76,12 @@ protected:
     bool overwriteConfigMessageBox(const QString &configName) const;
     Akonadi::Collection::Id convertPathToId(const QString &path);
     void backupResourceFile(const Akonadi::AgentInstance &agent, const QString &defaultPath);
-    void restoreResourceFile(const QString &resourceName, const QString &defaultPath, const QString &storePath);
+    void restoreResourceFile(const QString &resourceName, const QString &defaultPath, const QString &storePath, bool overwriteResources = false);
     bool backupFullDirectory(const KUrl &url, const QString &archivePath, const QString &archivename);
     virtual void addSpecificResourceSettings(KSharedConfig::Ptr resourceConfig, const QString &resourceName, QMap<QString, QVariant> &settings);
+    void restoreConfigFile(const QString &configNameStr);
+    bool overwriteDirectoryMessageBox(const QString &directory) const;
+    void overwriteDirectory(const QString &path, const KArchiveEntry *entry);
 
 
     KZip *archive();
@@ -95,6 +105,8 @@ protected:
     const KArchiveDirectory* mArchiveDirectory;
     int mNumberOfStep;
     PimCommon::CreateResource *mCreateResource;
+    QStringList mAgentPaths;
+    static int sArchiveVersion;
 };
 
 #endif // ABSTRACTIMPORTEXPORTJOB_H
