@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013 Montel Laurent <montel@kde.org>
   
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,13 +20,14 @@
 
 #include "abstractimportexportjob.h"
 
+class QWidget;
 class ArchiveStorage;
 
-class PIMSETTINGEXPORT_EXPORT ExportAkregatorJob : public AbstractImportExportJob
+class ExportAkregatorJob : public AbstractImportExportJob
 {
     Q_OBJECT
 public:
-    explicit ExportAkregatorJob(QObject *parent, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep);
+    explicit ExportAkregatorJob(QWidget *parent, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep);
     ~ExportAkregatorJob();
 
     void start();
