@@ -18,20 +18,27 @@
 #ifndef IMPORTCALENDARJOB_H
 #define IMPORTCALENDARJOB_H
 
+#include "abstractimportexportjob.h"
+
 class ArchiveStorage;
 class QWidget;
 
-class ImportCalendarJob
+class ImportCalendarJob : public AbstractImportExportJob
 {
+    Q_OBJECT
 public:
-    explicit ImportCalendarJob(QWidget *parent, ArchiveStorage *archiveStorage);
+    explicit ImportCalendarJob(QWidget *parent, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep);
     ~ImportCalendarJob();
 
     void start();
 
 private:
+    void searchAllFiles(const KArchiveDirectory *dir,const QString &prefix);
+    void storeCalendarArchiveResource(const KArchiveDirectory *dir, const QString &prefix);
+    void importkorganizerConfig(const KArchiveFile* file, const QString &config, const QString &filename,const QString &prefix);
     void restoreResources();
     void restoreConfig();
+    void addSpecificResourceSettings(KSharedConfig::Ptr resourceConfig, const QString &resourceName, QMap<QString, QVariant> &settings);
 };
 
 #endif // IMPORTCALENDARJOB_H
