@@ -38,6 +38,7 @@
 #include <KProcess>
 
 #include <QDebug>
+#include <QFile>
 #include <QDir>
 
 ExportMailJob::ExportMailJob(QWidget *parent, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage,int numberOfStep)
@@ -64,6 +65,7 @@ void ExportMailJob::start()
     if (!checkProgram())
         return;
 
+    Q_EMIT title(i18n("Start export knotes settings..."));
     createProgressDialog();
 
     if (mTypeSelected & Utils::Identity) {
@@ -164,7 +166,6 @@ void ExportMailJob::backupResources()
                     if (!errorStr.isEmpty()) {
                         Q_EMIT error(errorStr);
                     }
-
                 } else {
                     qDebug()<<" resource \""<<identifier<<"\" will not store";
                 }
@@ -197,6 +198,8 @@ void ExportMailJob::backupConfig()
     backupConfigFile(QLatin1String("kmailsnippetrc"));
     backupConfigFile(QLatin1String("sievetemplaterc"));
     backupConfigFile(QLatin1String("customtemplatesrc"));
+    backupConfigFile(QLatin1String("kontactrc"));
+    backupConfigFile(QLatin1String("kontact_summaryrc"));
 
     //Notify file config
     backupConfigFile(QLatin1String("akonadi_mailfilter_agent.notifyrc"));
@@ -205,6 +208,37 @@ void ExportMailJob::backupConfig()
     backupConfigFile(QLatin1String("kmail2.notifyrc"));
     backupConfigFile(QLatin1String("akonadi_newmailnotifier_agent.notifyrc"));
     backupConfigFile(QLatin1String("akonadi_maildispatcher_agent.notifyrc"));
+    backupConfigFile(QLatin1String("akonadi_folderarchive_agent.notifyrc"));
+    backupConfigFile(QLatin1String("akonadi_followupreminder_agent.notifyrc"));
+    backupConfigFile(QLatin1String("messagevieweradblockrc"));
+    backupConfigFile(QLatin1String("messageviewer.notifyrc"));
+
+    const QString folderArchiveAgentConfigurationStr(QLatin1String("akonadi_folderarchive_agentrc"));
+    const QString folderArchiveAgentConfigurationrc = KStandardDirs::locateLocal( "config", folderArchiveAgentConfigurationStr );
+    if (QFile(folderArchiveAgentConfigurationrc).exists()) {
+        KSharedConfigPtr archivemailrc = KSharedConfig::openConfig(folderArchiveAgentConfigurationStr);
+
+        KTemporaryFile tmp;
+        tmp.open();
+
+        KConfig *archiveConfig = archivemailrc->copyTo( tmp.fileName() );
+        const QStringList archiveList = archiveConfig->groupList().filter( QRegExp( QLatin1String("FolderArchiveAccount ") ) );
+
+        Q_FOREACH(const QString& str, archiveList) {
+            KConfigGroup oldGroup = archiveConfig->group(str);
+            qint64 topLevelId = oldGroup.readEntry(QLatin1String("topLevelCollectionId"), -1);
+            if (topLevelId!=-1) {
+                const QString realPath = MailCommon::Util::fullCollectionPath(Akonadi::Collection( topLevelId ));
+                if (!realPath.isEmpty()) {
+                    oldGroup.writeEntry(QLatin1String("topLevelCollectionId"), realPath);
+                }
+            }
+        }
+        archiveConfig->sync();
+
+        backupFile(tmp.fileName(), Utils::configsPath(), folderArchiveAgentConfigurationStr);
+        delete archiveConfig;
+    }
 
     const QString archiveMailAgentConfigurationStr(QLatin1String("akonadi_archivemail_agentrc"));
     const QString archiveMailAgentconfigurationrc = KStandardDirs::locateLocal( "config", archiveMailAgentConfigurationStr );
@@ -286,6 +320,10 @@ void ExportMailJob::backupConfig()
             backupFile(listFileInfo.at(i).absoluteFilePath(), Utils::dataPath() + QLatin1String( "autocorrect/" ) , listFileInfo.at(i).fileName());
         }
     }
+    const QString adblockFilePath = KStandardDirs::locateLocal( "data", QLatin1String( "kmail2/adblockrules_local" ) );
+    if (!adblockFilePath.isEmpty()) {
+        backupFile(adblockFilePath, Utils::dataPath() + QLatin1String( "kmail2/" ) , QLatin1String("adblockrules_local"));
+    }
 
     const QString kmailStr(QLatin1String("kmail2rc"));
     const QString kmail2rc = KStandardDirs::locateLocal( "config",  kmailStr);
@@ -423,7 +461,7 @@ void ExportMailJob::backupIdentity()
                 QFile file(vcardFileName);
                 if (file.exists()) {
                     const bool fileAdded  = archive()->addLocalFile(vcardFileName, Utils::identitiesPath() + QString::number(uoid) + QDir::separator() + file.fileName());
-                    if (fileAdded)
+                    if (!fileAdded)
                         Q_EMIT error(i18n("vCard file \"%1\" cannot be saved.",file.fileName()));
                 } else {
                     group.deleteEntry(vcard);
@@ -463,12 +501,11 @@ void ExportMailJob::backupMails()
                     //Store akonadi agent config
                     KUrl url = Utils::resourcePath(agent);
 
-                    if (backupMailData(url, archivePath)) {
-                        const QString errorStr = Utils::storeResources(archive(), identifier, archivePath );
-                        if (!errorStr.isEmpty()) {
+                    const bool fileAdded = backupFullDirectory(url, archivePath, QLatin1String("mail.zip"));
+                    if (fileAdded) {
+                        const QString errorStr = Utils::storeResources(archive(), identifier, archivePath);
+                        if (!errorStr.isEmpty())
                             Q_EMIT error(errorStr);
-                        }
-                        Q_EMIT info(i18n("\"%1\" was backuped.",url.fileName()));
                         url = Utils::akonadiAgentConfigPath(identifier);
                         if (!url.isEmpty()) {
                             const QString filename = url.fileName();
@@ -478,7 +515,6 @@ void ExportMailJob::backupMails()
                             else
                                 Q_EMIT error(i18n("\"%1\" file cannot be added to backup file.",filename));
                         }
-
                     }
                 }
             }
@@ -502,51 +538,12 @@ void ExportMailJob::writeDirectory(const QString &path, const QString &relativeP
         if (lst.at(i).isDir()) {
             writeDirectory(relativePath + path + QLatin1Char('/') + filename,relativePath,mailArchive);
         } else {
-            QString currentPath(path);
-            mailArchive->addLocalFile(lst.at(i).absoluteFilePath(),currentPath + QLatin1Char('/') + filename);
+            const QString currentPath(currentPath + QLatin1Char('/') + filename);
+            mailArchive->addLocalFile(lst.at(i).absoluteFilePath(),currentPath);
         }
     }
 }
 
-bool ExportMailJob::backupMailData(const KUrl& url,const QString &archivePath)
-{
-    const QString filename = url.fileName();
-    KTemporaryFile tmp;
-    tmp.open();
-    KZip *mailArchive = new KZip(tmp.fileName());
-    bool result = mailArchive->open(QIODevice::WriteOnly);
-    if (!result) {
-        Q_EMIT error(i18n("Mail \"%1\" file cannot be added to backup file.",filename));
-        delete mailArchive;
-        return false;
-    }
-
-    QString relatifPath = url.path();
-    const int parentDirEndIndex = relatifPath.lastIndexOf( filename );
-    relatifPath = relatifPath.left( parentDirEndIndex );
-
-    writeDirectory(url.path(),relatifPath, mailArchive);
-    KUrl subDir = subdirPath(url);
-    if (QFile(subDir.path()).exists()) {
-        writeDirectory(subDir.path(),relatifPath,mailArchive);
-    }
-    mailArchive->close();
-
-    //TODO: store as an unique file
-    mailArchive->setCompression(KZip::NoCompression);
-    const bool fileAdded = archive()->addLocalFile(tmp.fileName(), archivePath + filename);
-    mailArchive->setCompression(KZip::DeflateCompression);
-    delete mailArchive;
-
-    if (fileAdded) {
-        Q_EMIT info(i18n("Mail \"%1\" was backuped.",filename));
-        return true;
-    } else {
-        Q_EMIT error(i18n("Mail \"%1\" file cannot be added to backup file.",filename));
-        return false;
-    }
-}
-
 void ExportMailJob::backupAkonadiDb()
 {
     showInfo(i18n("Backing up Akonadi Database..."));
@@ -615,8 +612,3 @@ KUrl ExportMailJob::subdirPath( const KUrl& url) const
     path.append( QLatin1Char('.') + filename + QLatin1String(".directory") );
     return KUrl(path);
 }
-
-QString ExportMailJob::componentName() const
-{
-    return QLatin1String("KMail");
-}
