@@ -66,15 +66,16 @@ ImportMailJob::~ImportMailJob()
 
 void ImportMailJob::start()
 {
+    Q_EMIT title(i18n("Start import kmail settings..."));
     mArchiveDirectory = archive()->directory();
     searchAllFiles(mArchiveDirectory,QString());
-    if (!mFileList.isEmpty()|| !mHashMailArchive.isEmpty()) {
+    if (!mFileList.isEmpty()|| !mListResourceFile.isEmpty()) {
         if (mTypeSelected & Utils::MailTransport)
             restoreTransports();
-        if (mTypeSelected & Utils::Resources)
-            restoreResources();
         if (mTypeSelected & Utils::Mails)
             restoreMails();
+        if (mTypeSelected & Utils::Resources)
+            restoreResources();
         if (mTypeSelected & Utils::Identity)
             restoreIdentity();
         if (mTypeSelected & Utils::Config)
@@ -97,7 +98,7 @@ void ImportMailJob::searchAllFiles(const KArchiveDirectory*dir,const QString&pre
             } else {
                 searchAllFiles(static_cast<const KArchiveDirectory*>(entry), newPrefix);
             }
-        } else {
+        } else if (entry) {
             const QString fileName = prefix.isEmpty() ? entry->name() : prefix + QLatin1Char('/') + entry->name();
             mFileList<<fileName;
         }
@@ -111,18 +112,24 @@ void ImportMailJob::storeMailArchiveResource(const KArchiveDirectory*dir, const
         if (entry && entry->isDirectory()) {
             const KArchiveDirectory*resourceDir = static_cast<const KArchiveDirectory*>(entry);
             const QStringList lst = resourceDir->entries();
-            //TODO implement it
             if (lst.count() >= 2) {
                 const QString archPath(prefix + QLatin1Char('/') + entryName + QLatin1Char('/'));
-                const QString name(lst.at(0));
-                if (name.endsWith(QLatin1String("rc"))&&
-                        (name.contains(QLatin1String("akonadi_mbox_resource_")) ||
-                         name.contains(QLatin1String("akonadi_mixedmaildir_resource_")) ||
-                         name.contains(QLatin1String("akonadi_maildir_resource_")))) {
-                    mHashMailArchive.insert(archPath + name,archPath +lst.at(1));
-                } else {
-                    mHashMailArchive.insert(archPath +lst.at(1),archPath + name);
+                resourceFiles files;
+                Q_FOREACH(const QString &name, lst) {
+                    if (name.endsWith(QLatin1String("rc"))&&
+                            (name.contains(QLatin1String("akonadi_mbox_resource_")) ||
+                             name.contains(QLatin1String("akonadi_mixedmaildir_resource_")) ||
+                             name.contains(QLatin1String("akonadi_maildir_resource_")))) {
+                        files.akonadiConfigFile = archPath + name;
+                    } else if (name.startsWith(Utils::prefixAkonadiConfigFile())) {
+                        files.akonadiAgentConfigFile = archPath + name;
+                    } else {
+                        files.akonadiResources = archPath + name;
+                    }
                 }
+                //Show debug:
+                files.debug();
+                mListResourceFile.append(files);
             } else {
                 kDebug()<<" Problem in archive. number of file "<<lst.count();
             }
@@ -309,8 +316,10 @@ void ImportMailJob::restoreResources()
                         settings.insert(QLatin1String("DownloadLater"),leaveOnserver.readEntry("downloadLater",QStringList()));
                     }
                     const QString newResource = mCreateResource->createResource( QString::fromLatin1("akonadi_pop3_resource"), filename, settings );
-                    if (!newResource.isEmpty())
+                    if (!newResource.isEmpty()) {
                         mHashResources.insert(filename,newResource);
+                        infoAboutNewResource(newResource);
+                    }
                 } else if (filename.contains(QLatin1String("imap"))) {
                     KConfigGroup network = resourceConfig->group(QLatin1String("network"));
                     if (network.hasKey(QLatin1String("Authentication"))) {
@@ -397,8 +406,10 @@ void ImportMailJob::restoreResources()
                     }
 
                     const QString newResource = mCreateResource->createResource( QString::fromLatin1("akonadi_imap_resource"), filename, settings );
-                    if (!newResource.isEmpty())
+                    if (!newResource.isEmpty()) {
                         mHashResources.insert(filename,newResource);
+                        infoAboutNewResource(newResource);
+                    }
                 } else {
                     kDebug()<<" problem with resource";
                 }
@@ -415,25 +426,38 @@ void ImportMailJob::restoreMails()
     QDir dir(mTempDirName);
     dir.mkdir(Utils::mailsPath());
     const QString copyToDirName(mTempDirName + QLatin1Char('/') + Utils::mailsPath());
-    QHashIterator<QString, QString> res(mHashMailArchive);
-    while (res.hasNext()) {
-        res.next();
-        const QString resourceFile = res.key();
+    for (int i = 0; i < mListResourceFile.size(); ++i) {
+
+        resourceFiles value = mListResourceFile.at(i);
+        value.debug();
+        const QString resourceFile = value.akonadiConfigFile;
         const KArchiveEntry* fileResouceEntry = mArchiveDirectory->entry(resourceFile);
         if (fileResouceEntry && fileResouceEntry->isFile()) {
             const KArchiveFile* file = static_cast<const KArchiveFile*>(fileResouceEntry);
             file->copyTo(copyToDirName);
-            const QString resourceName(file->name());
-            const QString filename(file->name());
-
+            QString resourceName(file->name());
+            QString filename(file->name());
+            qDebug()<<" filename "<<filename<<" resourceName"<<resourceName;
             KSharedConfig::Ptr resourceConfig = KSharedConfig::openConfig(copyToDirName + QLatin1Char('/') + resourceName);
 
-            KUrl newUrl = Utils::adaptResourcePath(resourceConfig, storeMails);
+            const KUrl newUrl = Utils::adaptResourcePath(resourceConfig, storeMails);
+
+            const QString agentConfigFile = value.akonadiAgentConfigFile;
+            if (!agentConfigFile.isEmpty()) {
+                const KArchiveEntry *akonadiAgentConfigEntry = mArchiveDirectory->entry(agentConfigFile);
+                if (akonadiAgentConfigEntry->isFile()) {
+                    const KArchiveFile* file = static_cast<const KArchiveFile*>(akonadiAgentConfigEntry);
+                    file->copyTo(copyToDirName);
+                    resourceName = file->name();
+                    KSharedConfig::Ptr akonadiAgentConfig = KSharedConfig::openConfig(copyToDirName + QLatin1Char('/') + resourceName);
+                    filename = Utils::akonadiAgentName(akonadiAgentConfig);
+                }
+            }
 
 
             QMap<QString, QVariant> settings;
             if (resourceName.contains(QLatin1String("akonadi_mbox_resource_"))) {
-                const QString dataFile = res.value();
+                const QString dataFile = value.akonadiResources;
                 const KArchiveEntry* dataResouceEntry = mArchiveDirectory->entry(dataFile);
                 if (dataResouceEntry->isFile()) {
                     const KArchiveFile* file = static_cast<const KArchiveFile*>(dataResouceEntry);
@@ -474,6 +498,7 @@ void ImportMailJob::restoreMails()
                 const QString newResource = mCreateResource->createResource( QString::fromLatin1("akonadi_mbox_resource"), filename, settings );
                 if (!newResource.isEmpty()) {
                     mHashResources.insert(filename,newResource);
+                    infoAboutNewResource(newResource);
                 }
 
             } else if (resourceName.contains(QLatin1String("akonadi_maildir_resource_")) ||
@@ -493,13 +518,15 @@ void ImportMailJob::restoreMails()
                 const QString newResource = mCreateResource->createResource( resourceName.contains(QLatin1String("akonadi_mixedmaildir_resource_")) ?
                                                                                  QString::fromLatin1("akonadi_mixedmaildir_resource")
                                                                                : QString::fromLatin1("akonadi_maildir_resource")
-                                                                                 , filename, settings );
-                if (!newResource.isEmpty())
+                                                                                 , filename, settings, true );
+                if (!newResource.isEmpty()) {
                     mHashResources.insert(filename,newResource);
+                    infoAboutNewResource(newResource);
+                }
 
-                const QString mailFile = res.value();
+                const QString mailFile = value.akonadiResources;
                 const KArchiveEntry* dataResouceEntry = mArchiveDirectory->entry(mailFile);
-                if (dataResouceEntry->isFile()) {
+                if (dataResouceEntry && dataResouceEntry->isFile()) {
                     const KArchiveFile* file = static_cast<const KArchiveFile*>(dataResouceEntry);
                     //TODO Fix me not correct zip filename.
                     extractZipFile(file, copyToDirName, newUrl.path());
@@ -627,6 +654,22 @@ void ImportMailJob::restoreConfig()
         }
     }
 
+
+    const QString folderarchiveconfigurationrcStr(QLatin1String("akonadi_folderarchive_agentrc"));
+    const KArchiveEntry* folderarchiveconfigurationentry  = mArchiveDirectory->entry(Utils::configsPath() + folderarchiveconfigurationrcStr);
+    if ( folderarchiveconfigurationentry && folderarchiveconfigurationentry->isFile()) {
+        const KArchiveFile* folderarchiveconfiguration = static_cast<const KArchiveFile*>(folderarchiveconfigurationentry);
+        const QString folderarchiveconfigurationrc = KStandardDirs::locateLocal( "config",  folderarchiveconfigurationrcStr);
+        if (QFile(folderarchiveconfigurationrc).exists()) {
+            if (overwriteConfigMessageBox(folderarchiveconfigurationrcStr)) {
+                importFolderArchiveConfig(folderarchiveconfiguration, folderarchiveconfigurationrc, folderarchiveconfigurationrcStr, Utils::configsPath());
+            }
+        } else {
+            importFolderArchiveConfig(folderarchiveconfiguration, folderarchiveconfigurationrc, folderarchiveconfigurationrcStr, Utils::configsPath());
+        }
+    }
+
+
     const QString templatesconfigurationrcStr(QLatin1String("templatesconfigurationrc"));
     const KArchiveEntry* templatesconfigurationentry  = mArchiveDirectory->entry(Utils::configsPath() + templatesconfigurationrcStr);
     if ( templatesconfigurationentry &&  templatesconfigurationentry->isFile()) {
@@ -688,6 +731,24 @@ void ImportMailJob::restoreConfig()
         }
     }
 
+    const QString adblockStr(QLatin1String("messagevieweradblockrc"));
+    const KArchiveEntry* adblockentry  = mArchiveDirectory->entry(Utils::configsPath() + adblockStr);
+    if ( adblockentry &&  adblockentry->isFile()) {
+        const KArchiveFile* adblockconfiguration = static_cast<const KArchiveFile*>(adblockentry);
+        const QString adblockrc = KStandardDirs::locateLocal( "config",  adblockStr);
+        if (QFile(adblockrc).exists()) {
+            //TODO 4.12 allow to merge config.
+            if (overwriteConfigMessageBox(adblockStr)) {
+                copyToFile(adblockconfiguration, adblockrc, adblockStr, Utils::configsPath());
+            }
+        } else {
+            copyToFile(adblockconfiguration, adblockrc, adblockStr, Utils::configsPath());
+        }
+    }
+
+    restoreConfigFile(QLatin1String("kontactrc"));
+
+    restoreConfigFile(QLatin1String("kontact_summaryrc"));
     //Restore notify file
     QStringList lstNotify;
     lstNotify << QLatin1String("akonadi_mailfilter_agent.notifyrc")
@@ -695,22 +756,14 @@ void ImportMailJob::restoreConfig()
               << QLatin1String("akonadi_archivemail_agent.notifyrc")
               << QLatin1String("kmail2.notifyrc")
               << QLatin1String("akonadi_newmailnotifier_agent.notifyrc")
-              << QLatin1String("akonadi_maildispatcher_agent.notifyrc");
+              << QLatin1String("akonadi_maildispatcher_agent.notifyrc")
+              << QLatin1String("akonadi_folderarchive_agent.notifyrc")
+              << QLatin1String("akonadi_followupreminder_agent.notifyrc")
+              << QLatin1String("messageviewer.notifyrc");
 
     //We can't merge it.
     Q_FOREACH (const QString &filename, lstNotify) {
-        const KArchiveEntry* notifyentry  = mArchiveDirectory->entry(Utils::configsPath() + filename);
-        if ( notifyentry &&  notifyentry->isFile()) {
-            const KArchiveFile* notify = static_cast<const KArchiveFile*>(notifyentry);
-            const QString notifyrc = KStandardDirs::locateLocal( "config",  filename);
-            if (QFile(notifyrc).exists()) {
-                if (overwriteConfigMessageBox(filename)) {
-                    copyToFile(notify, notifyrc, filename, Utils::configsPath());
-                }
-            } else {
-                copyToFile(notify, notifyrc, filename, Utils::configsPath());
-            }
-        }
+        restoreConfigFile(filename);
     }
 
 
@@ -725,15 +778,27 @@ void ImportMailJob::restoreConfig()
                 QString autocorrectionPath = KGlobal::dirs()->saveLocation("data", QLatin1String("autocorrect/"), false);
                 if (QFile(autocorrectionPath).exists()) {
                     if (overwriteConfigMessageBox(name)) {
-                        copyToFile(autocorrectionFile, autocorrectionPath, name, Utils::dataPath() + QLatin1String( "autocorrect/" ));
+                        copyToFile(autocorrectionFile, autocorrectionPath + QLatin1Char('/') + name, name, Utils::dataPath() + QLatin1String( "autocorrect/" ));
                     }
                 } else {
                     autocorrectionPath = KGlobal::dirs()->saveLocation("data", QLatin1String("autocorrect/"), true);
-                    copyToFile(autocorrectionFile, autocorrectionPath, name, Utils::dataPath() + QLatin1String( "autocorrect/" ));
+                    copyToFile(autocorrectionFile, autocorrectionPath + QLatin1Char('/') + name, name, Utils::dataPath() + QLatin1String( "autocorrect/" ));
                 }
             }
         }
     }
+    const KArchiveEntry* kmail2Entry  = mArchiveDirectory->entry(Utils::dataPath() + QLatin1String( "kmail2/adblockrules_local" ) );
+    if (kmail2Entry && kmail2Entry->isFile()) {
+        const KArchiveFile *entry = static_cast<const KArchiveFile*>(kmail2Entry);
+        const QString adblockPath = KGlobal::dirs()->saveLocation( "data", QLatin1String( "kmail2") + QLatin1String("/adblockrules_local"), false);
+        if (QFile(adblockPath).exists()) {
+            if (overwriteConfigMessageBox(QLatin1String("adblockrules_local"))) {
+                copyToFile(entry, KGlobal::dirs()->saveLocation( "data", QLatin1String( "kmail2")) + QLatin1String("/adblockrules_local"), QLatin1String("adblockrules_local"), Utils::dataPath() + QLatin1String( "kmail2/"));
+            }
+        } else {
+            copyToFile(entry, KGlobal::dirs()->saveLocation( "data", QLatin1String( "kmail2")) + QLatin1String("/adblockrules_local"), QLatin1String("adblockrules_local"), Utils::dataPath() + QLatin1String( "kmail2/"));
+        }
+    }
 
     const KArchiveEntry* themeEntry  = mArchiveDirectory->entry(Utils::dataPath() + QLatin1String( "messageviewer/themes/" ) );
     if (themeEntry && themeEntry->isDirectory()) {
@@ -791,29 +856,30 @@ void ImportMailJob::restoreIdentity()
 
             const QString templates = QLatin1String("Templates");
             convertRealPathToCollection(group, templates);
+               if (oldUid != -1) {
+                    const QString vcard = QLatin1String("VCardFile");
+                    if (group.hasKey(vcard)) {
+                        const QString vcardFileName = group.readEntry(vcard);
+                        if (!vcardFileName.isEmpty()) {
 
-            if (oldUid != -1) {
-                const QString vcard = QLatin1String("VCardFile");
-                if (group.hasKey(vcard)) {
-                    const QString vcardFileName = group.readEntry(vcard);
-                    if (!vcardFileName.isEmpty()) {
-                        QFile file(vcardFileName);
-
-                        const KArchiveEntry* vcardEntry = mArchiveDirectory->entry(Utils::identitiesPath() + QString::number(oldUid) + QDir::separator() + file.fileName());
-                        if (vcardEntry && vcardEntry->isFile()) {
-                            const KArchiveFile* vcardFile = static_cast<const KArchiveFile*>(vcardEntry);
-                            QString vcardFilePath = KStandardDirs::locateLocal("appdata",file.fileName() );
-                            int i = 1;
-                            while(QFile(vcardFileName).exists()) {
-                                vcardFilePath = KStandardDirs::locateLocal("appdata", QString::fromLatin1("%1_%2").arg(i).arg(file.fileName()) );
-                                ++i;
+                            QFileInfo fileInfo(vcardFileName);
+                            QFile file(vcardFileName);
+                            const KArchiveEntry* vcardEntry = mArchiveDirectory->entry(Utils::identitiesPath() + QString::number(oldUid) + QDir::separator() + file.fileName());
+                            if (vcardEntry && vcardEntry->isFile()) {
+                                const KArchiveFile* vcardFile = static_cast<const KArchiveFile*>(vcardEntry);
+                                QString vcardFilePath = KStandardDirs::locateLocal("data",QString::fromLatin1("kmail2/%1").arg(fileInfo.fileName() ));
+                                int i = 1;
+                                while(QFile(vcardFileName).exists()) {
+                                    vcardFilePath = KStandardDirs::locateLocal("data", QString::fromLatin1("kmail2/%1_%2").arg(i).arg(fileInfo.fileName()) );
+                                    ++i;
+                                }
+                                vcardFile->copyTo(QFileInfo(vcardFilePath).absolutePath());
+                                group.writeEntry(vcard, vcardFilePath);
                             }
-                            vcardFile->copyTo(vcardFilePath);
-                            group.writeEntry(vcard, vcardFilePath);
                         }
                     }
                 }
-            }
+
             QString name =  group.readEntry(QLatin1String("Name"));
 
             KPIMIdentities::Identity* identity = &mIdentityManager->newFromScratch( uniqueIdentityName(name) );
@@ -857,10 +923,10 @@ void ImportMailJob::restoreAkonadiDb()
     Q_EMIT info(i18n("Restore Akonadi Database..."));
     MessageViewer::KCursorSaver busy( MessageViewer::KBusyPtr::busy() );
 
-    const KArchiveEntry* akonadiDataBaseEntry = mArchiveDirectory->entry(akonadiDbPath);
+    const KArchiveEntry *akonadiDataBaseEntry = mArchiveDirectory->entry(akonadiDbPath);
     if (akonadiDataBaseEntry && akonadiDataBaseEntry->isFile()) {
 
-        const KArchiveFile* akonadiDataBaseFile = static_cast<const KArchiveFile*>(akonadiDataBaseEntry);
+        const KArchiveFile *akonadiDataBaseFile = static_cast<const KArchiveFile*>(akonadiDataBaseEntry);
 
         KTemporaryFile tmp;
         tmp.open();
@@ -926,6 +992,24 @@ void ImportMailJob::importArchiveConfig(const KArchiveFile* archiveconfiguration
     archiveConfig->sync();
 }
 
+void ImportMailJob::importFolderArchiveConfig(const KArchiveFile* archiveconfiguration, const QString& archiveconfigurationrc, const QString&filename,const QString& prefix)
+{
+    copyToFile(archiveconfiguration,archiveconfigurationrc,filename,prefix);
+    KSharedConfig::Ptr archiveConfig = KSharedConfig::openConfig(archiveconfigurationrc);
+
+    const QStringList archiveList = archiveConfig->groupList().filter( QRegExp( QLatin1String("FolderArchiveAccount ") ) );
+
+    Q_FOREACH(const QString& str, archiveList) {
+        KConfigGroup oldGroup = archiveConfig->group(str);
+        const Akonadi::Collection::Id id = convertPathToId(oldGroup.readEntry(QLatin1String("topLevelCollectionId")));
+        if (id!=-1) {
+            oldGroup.writeEntry(QLatin1String("topLevelCollectionId"), id);
+        }
+    }
+
+    archiveConfig->sync();
+}
+
 
 void ImportMailJob::copyArchiveMailAgentConfigGroup(KSharedConfig::Ptr archiveConfigOrigin, KSharedConfig::Ptr archiveConfigDestination)
 {
@@ -1213,8 +1297,3 @@ void ImportMailJob::mergeSieveTemplate(const KArchiveFile *archivefile, const QS
     grpExisting.writeEntry(QLatin1String("templateCount"), numberOfExistingTemplate);
     grpExisting.sync();
 }
-
-QString ImportMailJob::componentName() const
-{
-    return QLatin1String("KMail");
-}
