@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013 Montel Laurent <montel@kde.org>
   
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,23 +19,22 @@
 #define IMPORTNOTESJOB_H
 
 #include "abstractimportexportjob.h"
-#include "pimsettingexporter_export.h"
-class ArchiveStorage;
 
-class PIMSETTINGEXPORT_EXPORT ImportNotesJob : public AbstractImportExportJob
+class ArchiveStorage;
+class QWidget;
+
+class ImportNotesJob : public AbstractImportExportJob
 {
     Q_OBJECT
 public:
-    explicit ImportNotesJob(QObject *parent, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep);
+    explicit ImportNotesJob(QWidget *parent, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep);
     ~ImportNotesJob();
 
     void start();
 
 private:
-    void importKNoteGlobalSettings(const KArchiveFile *kmailsnippet, const QString &kmail2rc, const QString &filename, const QString &prefix);
     void restoreConfig();
     void restoreData();
-    void restoreResources();
 };
 
 #endif // IMPORTNOTESJOB_H
