@@ -19,9 +19,10 @@
 #ifndef PIMSETTINGEXPORTERWINDOW_H
 #define PIMSETTINGEXPORTERWINDOW_H
 #include <kxmlguiwindow.h>
-
 class LogWidget;
 class AbstractImportExportJob;
+class KRecentFilesAction;
+class KUrl;
 
 class PimSettingExporterWindow: public KXmlGuiWindow
 {
@@ -33,15 +34,22 @@ public:
 private Q_SLOTS:
     void slotBackupData();
     void slotRestoreData();
-    void slotAddInfo(const QString& info);
-    void slotAddError(const QString& info);
+    void slotAddInfo(const QString &info);
+    void slotAddError(const QString &info);
+    void slotAddTitle(const QString &info);
+    void slotAddEndLine();
+    void slotSaveLog();
+    void slotShowStructureInfos();
+    void slotRestoreFile(const KUrl &url);
 
 private:
+    void loadData(const QString &filename);
     void executeJob();
     bool canZip() const;
     void setupActions(bool canZipFile);
     LogWidget *mLogWidget;
     AbstractImportExportJob *mImportExportData;
+    KRecentFilesAction *mRecentFilesAction;
 };
 
 
